@@ -17,7 +17,7 @@ public slots:
 	void setX(int x) {xni->setValue(x); }				//!< set dimension in x range
 	void setY(int y) {yni->setValue(y); }				//!< set dimension in y range
 	void setGap(double g) { gaple->setText(QString::number(g)); }	//!< set gap between plots
-	void setPanel(bool p=true) { panel->setChecked(p); }		//!< set panel plots
+	void setPanel(bool v=true) { panel->setChecked(v); }		//!< set panel plots
 	void Apply() { apply_clicked(); }
 private:
 	void applyPanel(int nrx, int nry,  double gap);
