@@ -9,12 +9,15 @@ class AverageListDialog : public ListDialog
 {
 	Q_OBJECT
 public:
-	AverageListDialog(Worksheet *p, Spreadsheet *s, const char *name);
-private slots:
-	void ok_clicked() { apply_clicked(); accept(); }
-	void apply_clicked();
+	AverageListDialog(MainWin *mw, const char *name);
+public slots:
+	void setN(int n) { nni->setValue(n); }		//!< set number of points to average
+	void Apply() { apply_clicked(); }
 private:
-	KLineEdit *nle;
+	KIntNumInput *nni;
+private slots:
+	void saveSettings();
+	int apply_clicked();
 };
 
 #endif // AVERAGELISTDIALOG_H
