@@ -7,18 +7,15 @@
 
 #include "ColormapReader.h"
 
-#ifdef HAVE_GL
-using namespace Qwt3D;
-#endif
 using namespace std;
 
-ColorMapPreview::ColorMapPreview( QWidget *parent ) 
-: QFrame( parent ) 
+ColorMapPreview::ColorMapPreview( QWidget *parent )
+: QFrame( parent )
 {
 	label_ = new QLabel(this);
 	setFrameShape( QFrame::StyledPanel );
 	setFrameShadow( QFrame::Sunken );
-	QGridLayout* layout = new QGridLayout( this, 1, 1, 10); 
+	QGridLayout* layout = new QGridLayout( this, 1, 1, 10);
 
 	layout->addWidget( label_, 0, 0, Qt::AlignJustify );
 }
@@ -39,12 +36,11 @@ void ColorMapPreview::previewUrl( const QUrl &u )
 bool ColorMapPreview::open(QString fname) {
 #ifdef HAVE_GL
 	ifstream file((const char*)fname.local8Bit());
-	
-	RGBA rgb;
+
+	Qwt3D::RGBA rgb;
 	cv.clear();
-	
-	while ( file ) 
-	{		
+
+	while ( file ) {
 		file >> rgb.r >> rgb.g >> rgb.b;
 		file.ignore(10000,'\n');
 		if (!file.good())
@@ -55,7 +51,7 @@ bool ColorMapPreview::open(QString fname) {
 			rgb.r /= 255;
 			rgb.g /= 255;
 			rgb.b /= 255;
-			cv.push_back(rgb);	
+			cv.push_back(rgb);
 		}
 	}
 
@@ -65,8 +61,8 @@ bool ColorMapPreview::open(QString fname) {
 	for (unsigned i=0; i!=cv.size(); ++i)
 	{
 		rgb = cv[i];
-		p.setPen(GL2Qt(rgb.r,rgb.g,rgb.b));
-		p.drawLine(QPoint(0,0),QPoint(pix_.width(),0));	
+		p.setPen(Qwt3D::GL2Qt(rgb.r,rgb.g,rgb.b));
+		p.drawLine(QPoint(0,0),QPoint(pix_.width(),0));
     p.translate( 0, -1 );
 	}
   p.end();
