@@ -9,24 +9,20 @@
 #include "Dialog.h"
 
 #include "FilterNETCDF.h"
-#include "FilterAUDIOFILE.h"
 #include "FilterCDF.h"
-#include "FilterMAGICK.h"
 
 class FileInfoDialog: public Dialog
 {
 	Q_OBJECT
 public:
-	FileInfoDialog(const char *name, QString filename);
+	FileInfoDialog(MainWin *mw, const char *name, QString filename);
 private slots:
 	void updateVarListBox();
 private:
 	QListBox *varlb, *selvarlb;	// listbox of all variables / for selected variable
 	QLabel *varlabel;			// label of selected variable
 	FilterNETCDF ncf;			// filter for netcdf files
-	FilterAUDIOFILE auf;		// filter for audiofile files
 	FilterCDF cdf;				// filter for cdf files
-	FilterMAGICK mf;			// filter for Magick images
 };
 
 #endif //FILEINFODIALOG_H
