@@ -21,6 +21,14 @@ Graph2D::Graph2D(QString n, QString l, LRange r[2], LSource src, PType t, Style
 	ptr = new Point[nr];
 	for(int i=0;i<nr;i++)
 		ptr[i] = p[i];
+
+	delete [] p;
+}
+
+Graph2D::~Graph2D() {
+	delete [] ptr;
+
+	delete label;
 }
 
 Graph2D *Graph2D::Clone() {
@@ -41,7 +49,7 @@ Graph2D *Graph2D::Clone() {
 	return newg;
 }
 
-QStringList Graph2D::Info() 
+QStringList Graph2D::Info()
 {
 	QStringList s;
 	QString t;
@@ -61,22 +69,18 @@ QStringList Graph2D::Info()
 	QString sh=i18n("NO");
 	if (shown)
 		sh=i18n("YES");
-	
+
 	s << label->simpleTitle() << t << sh;
 	s << QString::number(number);
 	s << QString(" 1 ");		// only 1 column
 	s << QString::number(range[0].rMin()) + " .. " + QString::number(range[0].rMax());
 	s << QString::number(range[1].rMin())+ " .. " + QString::number(range[1].rMax());
-/*	s << QString::number(style.Type()) << (style.Color()).name();
-	s << QString::number(style.isFilled()) << (style.FillColor()).name();
-	s << QString::number(symbol.getType()) << (symbol.getColor()).name();
-	s << QString::number(symbol.getSize());
-	s << QString::number(symbol.getFill()) << (symbol.getFillColor()).name() ;
-*/
+
 	return s;
 }
 
 void Graph2D::saveXML(QDomDocument doc, QDomElement graphtag) {
+	kdDebug()<<"Graph2D::saveXML()"<<endl;
 	QDomElement tag = doc.createElement( "Range" );
 	tag.setAttribute("xmin",QString::number(range[0].rMin()));
 	tag.setAttribute("xmax",QString::number(range[0].rMax()));
@@ -91,6 +95,7 @@ void Graph2D::saveXML(QDomDocument doc, QDomElement graphtag) {
 		tag.setAttribute("masked",QString::number(ptr[i].Masked()));
     		graphtag.appendChild( tag );
 	}
+	kdDebug()<<"Graph2D::saveXML() DONE"<<endl;
 }
 
 void Graph2D::openXML(QDomNode node) {
@@ -109,7 +114,7 @@ void Graph2D::openXML(QDomNode node) {
 			range[1].setRange(e.attribute("ymin").toDouble(),e.attribute("ymax").toDouble());
 		}
 		else if(e.tagName() == "Data") {
-			kdDebug()<<"I = "<<i<<" x ="<<e.attribute("x").toDouble()<<endl;
+			// kdDebug()<<"I = "<<i<<" x ="<<e.attribute("x").toDouble()<<endl;
 			ptr[i].setPoint(e.attribute("x").toDouble(),e.attribute("y").toDouble());
 			ptr[i].setMasked((bool) e.attribute("masked").toInt());
 			i++;
@@ -138,7 +143,7 @@ void Graph2D::save(QTextStream *t, QProgressDialog *progress) {
 
 void Graph2D::open(QTextStream *t, int version, QProgressDialog *progress) {
 	openGraph(t,version);
-	
+
 	if (version > 2)
 		*t>>number;
 	else if (version > 1 ) {
@@ -156,7 +161,7 @@ void Graph2D::open(QTextStream *t, int version, QProgressDialog *progress) {
 	range[1].setMin(ymin);
 	range[1].setMax(ymax);
 
-	// this belongs to openGraph() but the ranges are in between :-( 
+	// this belongs to openGraph() but the ranges are in between :-(
 	type = (PType) (style->open(t,version));
 	symbol->open(t,version);
 
@@ -164,7 +169,7 @@ void Graph2D::open(QTextStream *t, int version, QProgressDialog *progress) {
 	double x, y;
 	int m;
 	ptr = new Point[number];
-	
+
 	progress->setTotalSteps(number);
 	for (int i=0;i< number;i++) {
 		if(i%1000 == 0) progress->setProgress(i);
