@@ -28,7 +28,7 @@ public:
 	int addGraphIMAGE(GraphIMAGE *g);
 	int addGraphL(GraphL *g);
 	int delGraph(unsigned int index);
-	GRAPHType getStruct(int index);	
+	GRAPHType getType(int index);	
 	int Index(int index);	
 	Graph *getGraph(unsigned int index);
 	Graph2D *getGraph2D(int index);
@@ -37,16 +37,17 @@ public:
 	Graph4D *getGraph4D(int index);
 	GraphIMAGE *getGraphIMAGE(int index);
 	GraphL *getGraphL(int index);
-	unsigned int Number() { return nr2D+nr3D+nrM+nrGRASS+nr4D+nrIMAGE+nrL; }
-	unsigned int isNotFull() { return NR_TYPES*MAX_NR-nr2D-nr3D-nrM-nrGRASS-nr4D-nrIMAGE-nrL; }
+	unsigned int Number() { return nr2D+nr3D+nrM+nr4D+nrIMAGE+nrL; }
+	unsigned int isNotFull() { return NR_TYPES*MAX_NR-nr2D-nr3D-nrM-nr4D-nrIMAGE-nrL; }
 private:
-	unsigned int nr2D, nr3D, nrM, nrGRASS, nr4D, nrIMAGE, nrL;		// number of graphs
-	Graph2D list2D[MAX_NR];
-	Graph3D list3D[MAX_NR];
-	GraphM listM[MAX_NR];
-	Graph4D list4D[MAX_NR];
-	GraphIMAGE listIMAGE[MAX_NR];
-	GraphL listL[MAX_NR];
+	unsigned int nr2D, nr3D, nrM, nr4D, nrIMAGE, nrL;		// number of graphs
+	Graph2D* list2D[MAX_NR];
+	Graph3D* list3D[MAX_NR];
+	GraphM* listM[MAX_NR];
+	Graph4D* list4D[MAX_NR];
+	GraphIMAGE* listIMAGE[MAX_NR];
+	GraphL* listL[MAX_NR];
+	// order of types : see graphlist.h !
 	int id[NR_TYPES*MAX_NR];	// ID s   (0,1,-1,-1,-1,-1,...,2,4,-1,-1,...,3,-1,-1,-1,...)
 };
 
