@@ -12,19 +12,19 @@ class ImageMagickDialog: public Dialog
 {
 	Q_OBJECT
 public:
-	ImageMagickDialog(class MainWin *mw, QString fn="out.8bim", int f=0, int sx=800, int sy=600,
+	ImageMagickDialog(MainWin *mw, QString fn=i18n("out.8bim"), int f=0, int sx=800, int sy=600,
 		double r=0.0, const char *name=0);
 public slots:
-	void OK() { agree(); accept(); }
-	void agree();
-private slots:
-	void selectFile();
-	void updateFilename(int index);
+	void Apply() { apply_clicked(); accept(); }
 private:
-	class MainWin *mw;
 	QStringList formats;
 	KComboBox *format;
 	KLineEdit *filele, *xle, *yle, *rotle;
+private slots:
+	void saveSettings();
+	void apply_clicked();
+	void selectFile();
+	void updateFilename(int index);
 };
 
 #endif //IMAGEMAGICKDIALOG_H
