@@ -681,8 +681,9 @@ int ImportDialog::apply_clicked() {
 					// check for audio file
 					if ( !( filename.lower().contains(".dat") || filename.lower().contains(".txt") ||
 						filename.lower().contains(".bin") || filename.lower().contains(".csv")) ) {	// audiofile file
-						importAUDIOFILE(filename, ss, startRow, endRow);
-						break;
+						int status = importAUDIOFILE(filename, ss, startRow, endRow);
+						if(status == 0)
+							break;
 					}
 
 					QProgressDialog progress( i18n("Reading data ..."), i18n("Cancel"), file->size(),this,
