@@ -5,15 +5,12 @@
 
 #include <qfont.h>
 #include <qcheckbox.h>
-#include "Worksheet.h"
 #include "Dialog.h"
 
 class InfoDialog: public Dialog
 {
 public:
-	InfoDialog(Worksheet *p, const char *name,int item);
-private:
-	Worksheet *p;
+	InfoDialog(MainWin *m, const char *name, int item);
 };
 
 #endif //INFODIALOG_H
