@@ -11,7 +11,7 @@ class InterpolationListDialog : public ListDialog
 public:
 	InterpolationListDialog(MainWin *mw, const char *name);
 public slots:
-	void setType(int type) {typecb->setCurrentItem(type); }		//!< set type of interpolation
+	void setType(int v) {typecb->setCurrentItem(v); }		//!< set type of interpolation
 	void setRange(double a, double b) {						//!< set range for interpolation
 		ale->setText(QString::number(a)); ble->setText(QString::number(b)); }
 	void setFrom(double v) { ale->setText(QString::number(v)); }
