@@ -30,37 +30,43 @@ Label::Label(QString t, QFont f, QColor c) {
 	richtext = new QSimpleRichText(t,f);
 	boxed = false;
 	transparent = true;
-	bgcolor = QColor(Qt::white);
+	bgcolor = Qt::white;
 	rotation = 0.0;
 	is_texlabel = false;
 }
 
-int Label::Length() {
-	QSimpleRichText *richtext = new QSimpleRichText(title,font);
+Label::~Label() {
+	// crashes data dialog
+	// if(richtext)
+	//	delete richtext;
+}
 
-	return richtext->width();
+int Label::Length() {
+	QSimpleRichText *rt = new QSimpleRichText(title,font);
+
+	return rt->width();
 }
 
 QString Label::simpleTitle() {
 	QString t(title);
-	
+
 	t.replace(QRegExp(QString("\n")),"");	// replace newlines
-	
+
 	QRegExp rx("<.*>");		// remove all html tags
 	rx.setMinimal(true);
 	t.replace(rx,"");
-	
+
 	return t;
 }
 
 QStringList Label::Info() {
 	QStringList s;
-	
+
 	// no label
 	if(title.isEmpty())
 		return s;
 
-        s << QString::number(x) + "/" + QString::number(y);
+	s << QString::number(x) + "/" + QString::number(y);
 
 	return s;
 }
@@ -68,17 +74,17 @@ QStringList Label::Info() {
 void Label::save(QTextStream *ts) {
 	title.replace( QRegExp(QString("\n")), QString("") ); // strip all newlines from t
 	*ts<<title<<endl;
-	
+
 	*ts<<font.family()<<endl;
 	*ts<<font.pointSize()<<' ';
 	*ts<<font.weight()<<' '<<font.italic()<<endl;
-	
+
 	*ts<<color.name()<<endl;
-	
+
 	*ts<<x<<' '<<y<<endl;
 	*ts<<(int)boxed<<endl;
-	*ts<<rotation<<endl;	
-	*ts<<(int)is_texlabel<<endl;	
+	*ts<<rotation<<endl;
+	*ts<<(int)is_texlabel<<endl;
 
 	*ts<<bgcolor.name()<<endl;
 	*ts<<transparent<<endl;
@@ -133,7 +139,7 @@ void Label::open(QTextStream *ts,int version, bool skip) {
 		transparent=(bool)tmp;
 //		kdDebug()<<"	BGCOLOR : "<<bgcolor.name()<<endl;
 	}
-} 
+}
 
 QDomElement Label::saveXML(QDomDocument doc) {
 	QDomElement labeltag = doc.createElement( "Label" );
@@ -209,7 +215,7 @@ void Label::openXML(QDomNode node) {
 			bgcolor = QColor(e.text());
 		else if(e.tagName() == "Transparent")
 			transparent = (bool) e.text().toInt();
-	
+
 		node = node.nextSibling();
 	}
 }
@@ -241,14 +247,15 @@ void Label::readSettings(KConfig *config, QString entry) {
 }
 
 void Label::draw(Worksheet *ws, QPainter *p, Point pos, Point size, int w, int h, double phi) {
+//	kdDebug()<<"Label::draw()"<<endl;
 	if(is_texlabel) {
 #if KDE_VERSION > 0x030104
 		KTempDir *tmpdir = new KTempDir();
-		QString dirname = tmpdir->name();        
+		QString dirname = tmpdir->name();
 #else
 		QString dirname("/tmp/LabPlot-texvc");
 		mkdir(dirname.latin1(),S_IRWXU);
-#endif		
+#endif
 		KProcess *proc = new KProcess;
 		*proc << "texvc";
 		*proc << "/tmp"<<dirname<<title;
@@ -279,25 +286,25 @@ void Label::draw(Worksheet *ws, QPainter *p, Point pos, Point size, int w, int h
 			tmpdir->unlink();
 #else
 		rmdir(dirname.latin1());
-#endif		
+#endif
 			return;
 		}
 	}
-	
+
 	// resize font with plot size
-	QFont tmpfont = font;
+	QFont tmpfont(font);
 	int tmpsize = font.pointSize();
 	tmpfont.setPointSize((int)(size.X()*tmpsize));
 
-        if(richtext) delete richtext;
+	if(richtext) delete richtext;
 	richtext = new QSimpleRichText(title,tmpfont);
 	richtext->setWidth(p,500);
-	
+
 	p->save();
 	p->translate((pos.X()+x*size.X())*w,(pos.Y()+y*size.Y())*h);
 	// phi : normal angle, rotation : additional rotation
 	p->rotate(phi+rotation);
-	
+
 	if(!transparent) {
 		p->setBrush(bgcolor);
 		p->drawRect(-5,0,richtext->widthUsed(),richtext->height());
@@ -308,6 +315,8 @@ void Label::draw(Worksheet *ws, QPainter *p, Point pos, Point size, int w, int h
 	}
 	richtext->draw(p,0,0,QRect(),QColorGroup());
 	p->restore();
+
+//	kdDebug()<<"Label::draw() DONE"<<endl;
 }
 
 //! return true if mouse inside (x0,y0)
@@ -316,7 +325,7 @@ bool Label::inside(int x0, int y0, Point pos, Point size, int w, int h) {
 	int x2 = (int)(x1+richtext->widthUsed());	// right
 	int y1 = (int)(h*(pos.Y()+size.Y()*y));		// top
 	int y2 = (int)(y1+richtext->height());		// botton
-	
+
 	if (x0>x1 && x0<x2 && y0>y1 && y0<y2 )
 		return true;
 	return false;
@@ -330,7 +339,7 @@ bool Label::insideY(int x0, int y0, Point pos, Point size, int w, int h) {
 
 	//kdDebug()<<"Label::insideY()  X/Y    X1/X2 | Y1/Y2"<<endl;
 	//kdDebug()<<"       "<<x0<<' '<<y0<<"   "<<x1<<'/'<<x2<<" | "<<y1<<'/'<<y2<<endl;
-	
+
 	if (x0>x1 && x0<x2 && y0>y1 && y0<y2 )
 		return true;
 	return false;
@@ -341,7 +350,7 @@ bool Label::insideZ(int x0, int y0, Point pos, Point size, int w, int h) {
 	int x2 = (int)(w*(pos.X()+size.X()*x)+richtext->width());
 	int y1 = (int)(h*(pos.Y()+size.Y()*y)-richtext->height());
 	int y2 = (int)(h*(pos.Y()+size.Y()*y)+richtext->width());
-	
+
 	if (x0>x1 && x0<x2 && y0>y1 && y0<y2 )
 		return true;
 	return false;
