@@ -16,51 +16,59 @@
 #include "colors.h"
 #include "defs.h"
 
-ListDialog::ListDialog(MainWin *mw, const char *name)
-	: Dialog(mw, name)
+ListDialog::ListDialog(MainWin *m, const char *name)
+	: Dialog(m, name)
 {
-	if(p) {
-		type = p->getPlot(p->API())->Type();
+	kdDebug()<<"	ListDialog()"<<endl;
 
-		lv = new GraphListView(vbox);
-
-		// popup menu
-		menu = new QPopupMenu( lv );
-		menu->insertItem( i18n( "Show/Hide" ),this,SLOT(toggleShown()) );
-		menu->insertItem( i18n( "Add" ),this,SLOT(addGraph()) );
-		menu->insertItem( i18n( "Delete" ),this,SLOT(deleteGraph()) );
-		menu->insertItem( i18n( "Change" ),this,SLOT(changeGraph()) );
-		menu->insertItem( i18n( "Clone" ),this,SLOT(Clone()) );
-		menu->insertSeparator();
-		menu->insertItem( i18n( "Edit" ),this,SLOT(editGraph()) );
-		menu->insertItem( i18n( "Open Spreadsheet" ),this,SLOT(openSpreadsheet()) );
-		menu->insertItem( i18n( "Export" ),this,SLOT(dumpGraph()) );
-		menu->insertItem( i18n( "Statistics" ),this,SLOT(statGraph()) );
-		menu->insertSeparator();
-		menu->insertItem(i18n("different colors") ,this,SLOT(setDifferentColor()) );
-		menu->insertItem(i18n("different symbols") ,this,SLOT(setDifferentSymbol()) );
-		menu->insertItem(i18n("different line widths") ,this,SLOT(setDifferentWidth()) );
-		menu->insertItem(i18n("different line styles") ,this,SLOT(setDifferentStyle()) );
- 		menu->insertItem(i18n("black && white") ,this,SLOT(setBlackWhite()) );
- 		menu->insertSeparator();
-		menu->insertItem( i18n( "Toggle Masking" ),this,SLOT(toggleMask()) );
-		menu->insertItem( i18n( "Unmask" ),this,SLOT(unMask()) );
-		menu->insertItem( i18n( "Mask every n-th row" ),this,SLOT(nthMask()) );
-		menu->insertItem( i18n( "Mask all but n-th row" ),this,SLOT(firstMask()) );
-
-		// result selection
-		QHBox *hb = new QHBox(vbox);
-		sheetlabel = new QLabel(i18n("add result to "),hb);
-		sheetcb = new KComboBox(hb);
-		updateSheetList();
-
-		connect(lv, SIGNAL( rightButtonPressed( QListViewItem *, const QPoint& , int ) ),
-			this, SLOT( Menu(QListViewItem *, const QPoint& , int) ) );
-		connect(lv, SIGNAL( doubleClicked( QListViewItem *, const QPoint& , int ) ),
-			this, SLOT( changeGraph() ) );
-
-		updateList();
+	if(p==0) {
+		kdDebug()<<"	p==0"<<endl;
+		lv=0;
+		return;
 	}
+
+	Plot *plot = p->getPlot(p->API());
+	TESTPTR(plot);
+	type = plot->Type();
+
+	lv = new GraphListView(vbox);
+
+	// popup menu
+	menu = new QPopupMenu( lv );
+	menu->insertItem( i18n( "Show/Hide" ),this,SLOT(toggleShown()) );
+	menu->insertItem( i18n( "Add" ),this,SLOT(addGraph()) );
+	menu->insertItem( i18n( "Delete" ),this,SLOT(deleteGraph()) );
+	menu->insertItem( i18n( "Change" ),this,SLOT(changeGraph()) );
+	menu->insertItem( i18n( "Clone" ),this,SLOT(Clone()) );
+	menu->insertSeparator();
+	menu->insertItem( i18n( "Edit" ),this,SLOT(editGraph()) );
+	menu->insertItem( i18n( "Open Spreadsheet" ),this,SLOT(openSpreadsheet()) );
+	menu->insertItem( i18n( "Export" ),this,SLOT(dumpGraph()) );
+	menu->insertItem( i18n( "Statistics" ),this,SLOT(statGraph()) );
+	menu->insertSeparator();
+	menu->insertItem(i18n("different colors") ,this,SLOT(setDifferentColor()) );
+	menu->insertItem(i18n("different symbols") ,this,SLOT(setDifferentSymbol()) );
+	menu->insertItem(i18n("different line widths") ,this,SLOT(setDifferentWidth()) );
+	menu->insertItem(i18n("different line styles") ,this,SLOT(setDifferentStyle()) );
+ 	menu->insertItem(i18n("black && white") ,this,SLOT(setBlackWhite()) );
+ 	menu->insertSeparator();
+	menu->insertItem( i18n( "Toggle Masking" ),this,SLOT(toggleMask()) );
+	menu->insertItem( i18n( "Unmask" ),this,SLOT(unMask()) );
+	menu->insertItem( i18n( "Mask every n-th row" ),this,SLOT(nthMask()) );
+	menu->insertItem( i18n( "Mask all but n-th row" ),this,SLOT(firstMask()) );
+
+	// result selection
+	QHBox *hb = new QHBox(vbox);
+	sheetlabel = new QLabel(i18n("add result to "),hb);
+	sheetcb = new KComboBox(hb);
+	updateSheetList();
+
+	connect(lv, SIGNAL( rightButtonPressed( QListViewItem *, const QPoint& , int ) ),
+		this, SLOT( Menu(QListViewItem *, const QPoint& , int) ) );
+	connect(lv, SIGNAL( doubleClicked( QListViewItem *, const QPoint& , int ) ),
+		this, SLOT( changeGraph() ) );
+
+	updateList();
 }
 
 void ListDialog::updateSheetList() {
@@ -78,93 +86,104 @@ void ListDialog::updateSheetList() {
 }
 
 void ListDialog::updateList() {
+	kdDebug()<<"	ListDialog::updateList()"<<endl;
 	lv->clear();
 	lv->setSorting(-1);
 
-	// delete extra columns (needed ?)
-/*	while(lv->columns()>7) {
-		lv->removeColumn(lv->columns()-1);
-	}*/
-
 	GraphList *graphlist = p->getPlot(p->API())->getGraphList();
 	for (int i= graphlist->Number()-1;i>=0;i--) {
-		QStringList s;
-		GRAPHType st = graphlist->getStruct(i);
+		kdDebug()<<" using graph "<<i<<endl;
+		QStringList sl;
+		GRAPHType st = graphlist->getType(i);
 
 		if (type == P2D) {
-			if (st == GRAPH2D) {		// x-y
-				Graph2D *g = graphlist->getGraph2D(i);
-				s = g->Info();
-			}
+			if (st == GRAPH2D)		// x-y
+				sl = graphlist->getGraph2D(i)->Info();
 			else if (st == GRAPH3D) {	// x-y-dy
 				lv->showZ();
-				Graph3D *g = graphlist->getGraph3D(i);
-				s = g->Info();
+				sl = graphlist->getGraph3D(i)->Info();
 			}
 			else if (st == GRAPH4D) {	// x-y-dx-dy, x-y-dy1-dy2
 				lv->showZ();
 				lv->showT();
-				Graph4D *g = graphlist->getGraph4D(i);
-				s = g->Info();
+				sl = graphlist->getGraph4D(i)->Info();
 			}
 		}
-		else if (type == P3D ){
+		else if (type == P3D) {
 			if (st == GRAPH3D) {
 				lv->showZ();
-				Graph3D *g = graphlist->getGraph3D(i);
-				s = g->Info();
-			}
-			else if (st == GRAPHM){
-				GraphM *g = graphlist->getGraphM(i);
-				s = g->Info();
+				sl = graphlist->getGraph3D(i)->Info();
 			}
+			else if (st == GRAPHM)
+				sl = graphlist->getGraphM(i)->Info();
 		}
 		else if (type == PSURFACE) {
-			if (st == GRAPHM) {
-				GraphM *g = graphlist->getGraphM(i);
-				s = g->Info();
+			if (st == GRAPHM)
+				sl = graphlist->getGraphM(i)->Info();
+			else if (st == GRAPH3D)
+				sl = graphlist->getGraph3D(i)->Info();
+			else if (st == GRAPHIMAGE)
+				sl = graphlist->getGraphIMAGE(i)->Info();
+		}
+		else if (type == PPIE) {
+			if(st == GRAPH2D) {
+				Graph2D *graph = graphlist->getGraph2D(i);
+				if(graph !=0)
+					sl = graph->Info();
+				else
+					kdDebug()<<"			WARNING: graph "<<i<<" == 0!"<<endl;
 			}
-			else if (st == GRAPH3D) {
-				Graph3D *g = graphlist->getGraph3D(i);
-				s = g->Info();
-			}
-			else if (st == GRAPHIMAGE){
-				GraphIMAGE *g = graphlist->getGraphIMAGE(i);
-				s = g->Info();
+			else if (st == GRAPHL) {
+				GraphL *graph = graphlist->getGraphL(i);
+				if(graph !=0)
+					sl = graph->Info();
+				else
+					kdDebug()<<"			WARNING: graph "<<i<<" == 0!"<<endl;
 			}
 		}
-		else if (type == PPIE || type == PPOLAR) {
-			Graph2D *g = graphlist->getGraph2D(i);
-			s = g->Info();
+		else if (type == PPOLAR) {
+			Graph2D *graph = graphlist->getGraph2D(i);
+			if(graph !=0)
+				sl = graph->Info();
+			else
+				kdDebug()<<"			WARNING: graph "<<i<<" == 0!"<<endl;
+				
 		}
 		else if (type == PTERNARY) {
 			lv->showZ();
-			Graph3D *g = graphlist->getGraph3D(i);
-			s = g->Info();
+			sl = graphlist->getGraph3D(i)->Info();
 		}
 		else if (type == PQWT3D) {
-			if (st == GRAPHM) {
-				GraphM *g = graphlist->getGraphM(i);
-				s = g->Info();
-			}
-			else if (st == GRAPH3D) {
-				Graph3D *g = graphlist->getGraph3D(i);
-				s = g->Info();
-			}
+			if (st == GRAPHM)
+				sl = graphlist->getGraphM(i)->Info();
+			else if (st == GRAPH3D)
+				sl = graphlist->getGraph3D(i)->Info();
 		}
 		QListViewItem *lvi = new QListViewItem(lv);
-		for (unsigned int j = 0;j < s.count();j++) {
-			lvi->setText(j,s[j]);
+
+		// add icon with graph symbol
+		QPainter pa;
+		QPixmap pm( 30, 30 );
+		pm.fill(Qt::white);
+		pa.begin( &pm );
+		graphlist->getGraph(i)->drawStyle(&pa,0,15);
+		pa.end();
+
+		lvi->setPixmap(0,pm);
+
+		for (unsigned int j = 0;j < sl.count();j++) {
+			lvi->setText(j+1,sl[j]);
 		}
-//		kdDebug()<<"	NOW COLUMNS = "<<lv->columns()<<endl;	
+//		kdDebug()<<"	NOW COLUMNS = "<<lv->columns()<<endl;
 	}
-	
+
 	// select at least last item
 	lv->setSelected(lv->currentItem(),true);
-	
+
 	p->getMainWin()->setModified();
 	p->resetRanges();
 	p->updatePixmap();
+	kdDebug()<<"	ListDialog::updateList() DONE"<<endl;
 }
 
 void ListDialog::selectItem(int i) {
@@ -196,7 +215,7 @@ void ListDialog::toggleShown() {
 		else
 			g->setShown(true);
 	}
-	
+
 	updateList();
 	p->updatePixmap();
 	p->resetRanges();
@@ -207,7 +226,7 @@ void ListDialog::addGraph() {
 	kdDebug()<<"ListDialog::addGraph()"<<endl;
 	(new AddGraphDialog(mw, this, p->getPlot(p->API())->getGraphList(), 0))->show();
 }
-	
+
 // delete selected graph
 void ListDialog::deleteGraph() {
 	kdDebug()<<"ListDialog::deleteGraph()"<<endl;
@@ -223,10 +242,13 @@ void ListDialog::deleteGraph() {
 			continue;
 #endif
 		int item = (int) (lv->itemPos(it.current())/it.current()->height());
+		kdDebug()<<"	item = "<<item<<endl;
 		// shift item after deleted items
+		kdDebug()<<"	deleting graph "<<item-cur_item<<endl;
+		kdDebug()<<"	API="<<p->API()<<endl;
 		p->getPlot(p->API())->getGraphList()->delGraph(item - cur_item++);
 	}
-	
+
 	p->resetRanges();
 
 	updateList();
@@ -235,7 +257,7 @@ void ListDialog::deleteGraph() {
 
 void ListDialog::changeGraph() {
 	Plot *plot = p->getPlot(p->API());
-	PType type = plot->Type();
+	PType ptype = plot->Type();
 
 #if QT_VERSION > 0x030102
 	QListViewItemIterator it(lv,QListViewItemIterator::Selected);
@@ -250,10 +272,10 @@ void ListDialog::changeGraph() {
 		int item = (int) (lv->itemPos(it.current())/it.current()->height());
 		QString name = it.current()->text(0);
 
-		if(plot->getGraphList()->getGraph(item)->Source()==SDATA)		// data
-			(new DataDialog(mw,name,this,item,type))->show();
-		else		// function
-			(new FunctionDialog(mw,name,this,item,type))->show();
+		if(plot->getGraphList()->getGraph(item)->Source()==SDATA)
+			(new DataDialog(mw,name,this,item,ptype))->show();
+		else
+			(new FunctionDialog(mw,name,this,item,ptype))->show();
 	}
 }
 
@@ -291,38 +313,38 @@ void ListDialog::editGraph() {
 		QString name = it.current()->text(0);
 
 		GraphList *gl = p->getPlot(p->API())->getGraphList();
-		GRAPHType type = gl->getStruct(item);
-//		kdDebug()<<"STRUCT/TYPE = "<<type<<endl;
+		GRAPHType gtype = gl->getType(item);
+//		kdDebug()<<"STRUCT/TYPE = "<<gtype<<endl;
 
-		if(type == GRAPHIMAGE)	// image not editable
+		if(gtype == GRAPHIMAGE)	// image not editable
 			continue;
 
 		mw->newSpreadsheet();
-		Spreadsheet *s = mw->activeSpreadsheet();
+		Spreadsheet *ss = mw->activeSpreadsheet();
 
-		switch(type) {
+		switch(gtype) {
 		case GRAPH2D: {
 			Graph2D *g = gl->getGraph2D(item);
-			s->addGraph2D(g);
+			ss->addGraph2D(g);
 			}; break;
 		case GRAPH3D: {
 			Graph3D *g = gl->getGraph3D(item);
-			s->addGraph3D(g);
+			ss->addGraph3D(g);
 			}; break;
 		case GRAPH4D: {
 			Graph4D *g = gl->getGraph4D(item);
-			s->addGraph4D(g);
+			ss->addGraph4D(g);
 			}; break;
 		case GRAPHM: {
 			GraphM *g = gl->getGraphM(item);
-			s->addGraphM(g);
+			ss->addGraphM(g);
 			}; break;
 		default:
 			break;
 		}
 
-		s->setListDialog(this);
-		s->setGraph(gl->getGraph(item));
+		ss->setListDialog(this);
+		ss->setGraph(gl->getGraph(item));
 	}
 }
 
@@ -340,7 +362,7 @@ void ListDialog::openSpreadsheet() {
 		int item = (int) (lv->itemPos(it.current())/it.current()->height());
 
 		GraphList *gl = p->getPlot(p->API())->getGraphList();
-		GRAPHType st = gl->getStruct(item);
+		GRAPHType st = gl->getType(item);
 
 		Spreadsheet *spreadsheet = p->getMainWin()->newSpreadsheet();
 		QTable *table = spreadsheet->Table();
@@ -399,7 +421,7 @@ void ListDialog::openSpreadsheet() {
 			// set label for all columns
 			for (int i=1;i<table->numCols();i++)
 				table->horizontalHeader()->setLabel( i, QChar(i+65)+' '+i18n("{double}")+QString( " [Y]" ) );
-			
+
 			// TODO : set masked data
 			for(int i=0;i<g->NY();i++)
 				for(int j=0;j<g->NX();j++)
@@ -444,9 +466,9 @@ void ListDialog::openSpreadsheet() {
 			// set label for all columns
 			for (int i=1;i<table->numCols();i++)
 				table->horizontalHeader()->setLabel( i, QChar(i+65)+' '+i18n("{double}")+QString( " [Y]" ) );
-			
+
 			QImage image = pm.convertToImage();
-			
+
 			for (int i=0;i<pm.width();i++) {
 				for (int j=0;j<pm.height();j++) {
 					table->setText(j,i,QString::number(qGray(image.pixel(i,j))));
@@ -472,8 +494,8 @@ void ListDialog::statGraph() {
 #endif
 		int item = (int) (lv->itemPos(it.current())/it.current()->height());
 		QString name = it.current()->text(0);
-		
-		(new InfoDialog(p,name,item))->show();
+
+		(new InfoDialog(mw,name,item))->show();
 	}
 }
 
@@ -616,73 +638,73 @@ void ListDialog::mask(int how, int n) {
 			continue;
 #endif
 		int item = (int) (lv->itemPos(it.current())/it.current()->height());
-		GRAPHType s = gl->getStruct(item);
-		switch(s) {
+		GRAPHType gtype = gl->getType(item);
+		switch(gtype) {
 		case GRAPH2D: {
 			Graph2D *g = gl->getGraph2D(item);
-			Point *d = g->Data();
+			Point *data = g->Data();
 			for(int i=0;i<g->Number();i++) {
 				switch(how) {
 				case 0:
-					if(d[i].Masked())
-						d[i].setMasked(false);
+					if(data[i].Masked())
+						data[i].setMasked(false);
 					else
-						d[i].setMasked(true);
+						data[i].setMasked(true);
 					break;
 				case 1:
-					d[i].setMasked(false);
+					data[i].setMasked(false);
 					break;
 				case 2:
-					if(i%n==0) d[i].setMasked(true);
+					if(i%n==0) data[i].setMasked(true);
 					break;
-				case 3:	
-					if(i%n) d[i].setMasked(true);
+				case 3:
+					if(i%n) data[i].setMasked(true);
 					break;
 				}
 			}
 			}; break;
 		case GRAPH3D: {
 			Graph3D *g = gl->getGraph3D(item);
-			Point3D *d = g->Data();
+			Point3D *data = g->Data();
 			for(int i=0;i<g->Number();i++) {
 				switch(how) {
 				case 0:
-					if(d[i].Masked())
-						d[i].setMasked(false);
+					if(data[i].Masked())
+						data[i].setMasked(false);
 					else
-						d[i].setMasked(true);
+						data[i].setMasked(true);
 					break;
 				case 1:
-					d[i].setMasked(false);
+					data[i].setMasked(false);
 					break;
 				case 2:
-					if(i%n==0) d[i].setMasked(true);
+					if(i%n==0) data[i].setMasked(true);
 					break;
-				case 3:	
-					if(i%n) d[i].setMasked(true);
+				case 3:
+					if(i%n) data[i].setMasked(true);
 					break;
 				}
 			}
 			}; break;
 		case GRAPH4D: {
 			Graph4D *g = gl->getGraph4D(item);
-			Point4D *d = g->Data();
+			Point4D *data = g->Data();
 			for(int i=0;i<g->Number();i++) {
 				switch(how) {
 				case 0:
-					if(d[i].Masked())
-						d[i].setMasked(false);
+					if(data[i].Masked())
+						data[i].setMasked(false);
 					else
-						d[i].setMasked(true);
+						data[i].setMasked(true);
 					break;
 				case 1:
-					d[i].setMasked(false);
+					data[i].setMasked(false);
 					break;
 				case 2:
-					if(i%n==0) d[i].setMasked(true);
+					if(i%n==0) data[i].setMasked(true);
 					break;
-				case 3:	
-					if(i%n) d[i].setMasked(true);
+				case 3:
+					if(i%n) data[i].setMasked(true);
 					break;
 				}
 			}
@@ -702,17 +724,17 @@ void ListDialog::toggleMask() { mask(0,0); }
 void ListDialog::unMask() { mask(1,0); }
 
 void ListDialog::nthMask() {
-	bool ok;
-	int n = QInputDialog::getInteger(i18n("Mask every n-th row"),i18n("n = "),10,1,INF,1,&ok);
-	if(!ok) return;
+	bool res;
+	int n = QInputDialog::getInteger(i18n("Mask every n-th row"),i18n("n = "),10,1,INF,1,&res);
+	if(!res) return;
 
 	mask(2,n);
 }
 
 void ListDialog::firstMask() {
-	bool ok;
-	int n = QInputDialog::getInteger(i18n("Mask all but n-th row"),i18n("n = "),10,1,INF,1,&ok);
-	if(!ok) return;
+	bool res;
+	int n = QInputDialog::getInteger(i18n("Mask all but n-th row"),i18n("n = "),10,1,INF,1,&res);
+	if(!res) return;
 
 	mask(3,n);
 }
@@ -721,23 +743,22 @@ void ListDialog::firstMask() {
 void ListDialog::Clone() {
 	// TODO : use GraphXX::Clone() instead
 	Plot *plot = p->getPlot(p->API());
-	PType type = plot->Type();
+	PType ptype = plot->Type();
 	GraphList *gl = plot->getGraphList();
 	if(gl->Number()==0)
 		return;
-	
+
 	int item = (int) (lv->itemPos(lv->currentItem())/lv->currentItem()->height());
 
-	GRAPHType s = gl->getStruct(item);
 	int sheet = sheetcb->currentItem();
-	switch(s) {
+	switch(gl->getType(item)) {
 	case GRAPH2D: {
 		Graph2D *g = gl->getGraph2D(item)->Clone();
-		mw->addGraph2D(g,sheet,type);
+		mw->addGraph2D(g,sheet,ptype);
 		}; break;
 	case GRAPH3D: {
 		Graph3D *g = gl->getGraph3D(item)->Clone();
-		mw->addGraph3D(g,sheet,type);
+		mw->addGraph3D(g,sheet,ptype);
 		}; break;
 	case GRAPH4D: {
 		Graph4D *g = gl->getGraph4D(item)->Clone();
@@ -745,7 +766,7 @@ void ListDialog::Clone() {
 		}; break;
 	case GRAPHM: {
 		GraphM *g = gl->getGraphM(item)->Clone();
-		mw->addGraphM(g,sheet,type);
+		mw->addGraphM(g,sheet,ptype);
 		}; break;
 	case GRAPHIMAGE: {
 		GraphIMAGE *g = gl->getGraphIMAGE(item)->Clone();
@@ -767,10 +788,9 @@ void ListDialog::updateRange(int axis) {
 		return;
 	int item = (int) (lv->itemPos(lv->currentItem())/lv->currentItem()->height());
 
-	GRAPHType s = gl->getStruct(item);
 	LRange range=0;
 
-	if (s == GRAPH2D) {
+	if (gl->getType(item) == GRAPH2D) {
 		Graph2D *g = gl->getGraph2D(item);
 		range = g->Range(axis);
 		ale->setText(QString::number(range.rMin()));
