@@ -12,13 +12,17 @@ class OverlayPlotDialog: public PlotDialog
 {
 	Q_OBJECT
 public:
-	OverlayPlotDialog(Worksheet *p, const char *name);
+	OverlayPlotDialog(MainWin *mw, const char *name);
 public slots:
-	void ok_clicked() { apply_clicked(); accept(); }
-	void apply_clicked();
+	void setFirst(int i) { ani->setValue(i); }	//!< set first plot
+	void setSecond(int i) { bni->setValue(i); }	//!< set second plot
+	void Apply() { apply_clicked(); }
 private:
-	Worksheet *p;
-	KLineEdit *ale, *ble;
+	KIntNumInput *ani, *bni;
+private slots:
+	void ok_clicked() { apply_clicked(); accept(); }
+	void saveSettings();
+	void apply_clicked();
 };
 
 #endif //OVERLAYPLOTDIALOG_H
