@@ -15,20 +15,28 @@ using namespace std;
 // general 2D Plot class
 Plot2D::Plot2D(Worksheet *p)
 	: Plot(p) {
-	if(p==0) kdDebug()<<"no Worksheet defined!"<<endl;
-	QFont font = p->getMainWin()->defaultFont();
+	kdDebug()<<"Plot2D::Plot2D()"<<endl;
+
+	QFont font;
+	if(p==0)
+		kdDebug()<<"WARNING : no Worksheet defined!"<<endl;
+	else {
+		MainWin *mw = p->getMainWin();
+		if(mw)
+			font = mw->defaultFont();
+	}
 	font.setPointSize((int)(0.7*font.pointSize()));	// for axes label
 	kdDebug()<<"Plot2D()"<<endl;
 
-	// set default axis settings for all axes
-	for(int i=0;i<4;i++)
-		readAxisSettings(&axis[i],P2D,i);
-
 	axis[0].setLabel(new Label(i18n("x-Axis"),font));
 	axis[1].setLabel(new Label(i18n("y-Axis"),font));
 	axis[2].setLabel(new Label(i18n("y2-Axis"),font));
 	axis[3].setLabel(new Label(i18n("x2-Axis"),font));
-	
+
+	// set default axis settings for all axes
+	for(int i=0;i<4;i++)
+		readAxisSettings(&axis[i],P2D,i);
+
 	// set default font
 	font.setPointSize((int)(0.7*font.pointSize()));	// for tic label
 	axis[0].setTickLabelFont(font);
@@ -36,7 +44,17 @@ Plot2D::Plot2D(Worksheet *p)
 	axis[2].setTickLabelFont(font);
 	axis[3].setTickLabelFont(font);
 
-	kdDebug()<<"Plot2D OK"<<endl;
+	kdDebug()<<"Plot2D::Plot2D() DONE"<<endl;
+}
+
+Plot2D::~Plot2D() {
+	delete graphlist;
+
+	delete title;
+	delete markx;
+	delete marky;
+
+	delete region;
 }
 
 void Plot2D::setActRange(LRange* r,int i) {
@@ -133,8 +151,8 @@ void Plot2D::draw(QPainter *p, int w, int h) {
 	int ymin = (int)(h*(size.Y()*p1.Y()+position.Y()));
 	int ymax = (int)(h*(size.Y()*p2.Y()+position.Y()));
 
-//	kdDebug()<<"	XMIN/MXAX/YMIN/YMAX = "<<xmin<<','<<xmax<<','<<ymin<<','<<ymax<<endl;
-//	kdDebug()<<"	p1 = "<<p1.X()<<'/'<<p1.Y()<<" p2 = "<<p2.X()<<'/'<<p2.Y()<<endl;
+	kdDebug()<<"	XMIN/MXAX/YMIN/YMAX = "<<xmin<<','<<xmax<<','<<ymin<<','<<ymax<<endl;
+	kdDebug()<<"	p1 = "<<p1.X()<<'/'<<p1.Y()<<" p2 = "<<p2.X()<<'/'<<p2.Y()<<endl;
 
 	if (!transparent) {
 		// background color
@@ -143,14 +161,20 @@ void Plot2D::draw(QPainter *p, int w, int h) {
 		p->drawRect((int)(w*position.X()),(int)(h*position.Y()),(int)(w*size.X()),(int)(h*size.Y()));
 
 		// graph background color
+		if(gbgcolor.style() != Qt::SolidPattern) {	// don't draw plot background pattern in graph area
+			p->setBrush(QBrush(Qt::white,Qt::SolidPattern));
+			p->setPen(Qt::NoPen);
+			p->drawRect(xmin,ymin,xmax-xmin,ymax-ymin);
+		}
 		p->setBrush(gbgcolor);
 		p->setPen(Qt::NoPen);
 		p->drawRect(xmin,ymin,xmax-xmin,ymax-ymin);
 	}
 
-//	kdDebug()<<"	title->draw() pos:"<<position.X()<<' '<<position.Y()<<endl;
-//	kdDebug()<<" 	size:"<<size.X()<<' '<<size.Y()<<endl;
-	title->draw(worksheet,p,position,size,w,h,0);
+	kdDebug()<<"	title->draw() pos:"<<position.X()<<' '<<position.Y()<<endl;
+	kdDebug()<<" 	size:"<<size.X()<<' '<<size.Y()<<endl;
+	if(title != 0)
+		title->draw(worksheet,p,position,size,w,h,0);
 
 	drawAxes(p,w,h);
 	drawBorder(p,w,h);
@@ -253,7 +277,7 @@ void Plot2D::draw(QPainter *p, int w, int h) {
 		default: break;
 		}
 
-		//kdDebug()<<"REGION : "<<minx<<" "<<maxx<<endl;
+		// kdDebug()<<"REGION : "<<minx<<" "<<maxx<<endl;
 
 		if(minx != maxx) {
 			p->drawLine(minx,ymin,minx,ymax);
@@ -331,11 +355,11 @@ void Plot2D::draw(QPainter *p, int w, int h) {
 			break;
 		default: break;
 		}
-		
+
 		p->setPen(QPen(Qt::gray,1,Qt::DashLine));
 		p->setFont(QFont("Adobe Times",8));
 		QPointArray a;
-		if(minx>xmin-clipoffset&&minx<xmax+clipoffset) { 
+		if(minx>xmin-clipoffset&&minx<xmax+clipoffset) {
 			p->drawLine(minx,ymin,minx,ymax);	// mark x1
 			a.setPoints(3,minx,ymax,minx+2,ymax+4,minx-2,ymax+4);
 			p->drawPolygon(a);
@@ -343,7 +367,7 @@ void Plot2D::draw(QPainter *p, int w, int h) {
 			p->drawPolygon(a);
 			p->drawText(minx+5,ymax+10,QString::number(markx->rMin()));
 		}
-		if(maxx>xmin-clipoffset&&maxx<xmax+clipoffset) { 
+		if(maxx>xmin-clipoffset&&maxx<xmax+clipoffset) {
 			p->drawLine(maxx,ymin,maxx,ymax);	// mark x2
 			a.setPoints(3,maxx,ymax,maxx+2,ymax+4,maxx-2,ymax+4);
 			p->drawPolygon(a);
@@ -357,7 +381,7 @@ void Plot2D::draw(QPainter *p, int w, int h) {
 			p->drawPolygon(a);
 			a.setPoints(3,xmax,miny,xmax+4,miny+2,xmax+4,miny-2);
 			p->drawPolygon(a);
-			
+
 			p->save();
 			p->translate(xmin-5,miny-5);
 			p->rotate(-90);
@@ -395,7 +419,7 @@ void Plot2D::draw(QPainter *p, int w, int h) {
 		if (type == PSURFACE) {		// legend can't do this :-(
 			if (legend.X() == 0.7 && legend.Y() == 0.05 ) // replace the legend for surface plots first time
 				legend.setPosition(0.83,0.05);
-			
+
 			int x = (int) (w*(size.X()*legend.X()+position.X()));
 			int y = (int) (h*(size.Y()*legend.Y()+position.Y()));
 
@@ -410,9 +434,11 @@ void Plot2D::draw(QPainter *p, int w, int h) {
 //		legend.draw(p,type,graphlist,position,size,w,h);
 //		kdDebug()<<" drawing legend with pos = "<<position.X()<<' '<<position.Y()<<endl;
 //		kdDebug()<<" 	size.X()*w/size.Y()*h = "<<size.X()*w<<' '<<size.Y()*h<<endl;
-		
+
 	}
 	p->setPen(Qt::NoPen);
+
+	kdDebug()<<"Plot2D::draw() DONE"<<endl;
 }
 
 void Plot2D::drawBorder(QPainter *p,int w,int h) {
@@ -441,7 +467,8 @@ void Plot2D::drawBorder(QPainter *p,int w,int h) {
 	}
 }
 
-void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
+void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis a, int k) {
+//	kdDebug()<<"Plot2D::drawAxesTicks()"<<endl;
 	int xmin = (int)(w*(size.X()*p1.X()+position.X()));
 	int xmax = (int)(w*(size.X()*p2.X()+position.X()));
 	int ymin = (int)(h*(size.Y()*p1.Y()+position.Y()));
@@ -454,12 +481,12 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 	case 2: tmpi=6; axistype=1; break;
 	case 3: tmpi=4; break;
 	}
-	
-	if (axis.MajorTicksEnabled() && axis.Enabled()) {
+
+	if (a.MajorTicksEnabled() && a.Enabled()) {
 		double min = actrange[axistype].rMin();
 		double max = actrange[axistype].rMax();
-		TScale scale = axis.Scale();
-		int pos = axis.Position();
+		TScale scale = a.Scale();
+		int pos = a.Position();
 		if(pos) {
 			p->setPen(Qt::SolidLine);
 			if (axistype == 0)
@@ -467,12 +494,12 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 			else
 				p->drawLine((int)((xmin+xmax)/2.0),ymin,(int)((xmax+xmin)/2.0),ymax);
 		}
-		
-		if(axis.tickType() == 0 || scale != LINEAR) {	// Tick Type NUMBER and all nonlinear scales
+
+		if(a.tickType() == 0 || scale != LINEAR) {	// Tick Type NUMBER and all nonlinear scales
 			int t=-1;		// number of major tics
 			switch (scale) {
-			case LINEAR: case SQRT : case SX2: 
-				t = (int) axis.MajorTicks(); 
+			case LINEAR: case SQRT : case SX2:
+				t = (int) a.MajorTicks();
 				if(t==-1)
 					t=autoTicks(min,max);
 				break;
@@ -481,11 +508,11 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 			case LN: t = (int) log(max/min)+2; break;
 			}
 			if(t==0) t=-1;
-//			kdDebug()<<"	T="<<t<<endl;
-		
+			kdDebug()<<"	T="<<t<<endl;
+
 			for (int i = 0;i <= t; i++) {
 				int x1=0, x2=0, y1=0,y2=0;
-				
+
 				if(axistype == 0) {	// X Major Ticks
 					switch(scale) {
 					case LINEAR: {
@@ -519,14 +546,14 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 						x2 = xmin+(i+1)*(i+1)*(xmax-xmin)/(t*t);
 						} break;
 					}
-				
+
 					if(x1<=xmax+1 && x1>=xmin-1) { // major tics
-						p->setPen(QPen(axis.TickColor(),axis.majorTickWidth()));
+						p->setPen(QPen(a.TickColor(),a.majorTickWidth()));
 						if(k==0) {	// x
 							int ypos = ymax;
 							if(pos)
 								ypos = (int) ((ymax+ymin)/2.0);
-							switch(axis.TickPos()) {
+							switch(a.TickPos()) {
 							case 0: p->drawLine(x1,ypos,x1,ypos+10); break;
 							case 1: p->drawLine(x1,ypos-10,x1,ypos); break;
 							case 2: p->drawLine(x1,ypos-10,x1,ypos+10); break;
@@ -537,16 +564,16 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 							int ypos = ymin;
 							if(pos)
 								ypos = (int) ((ymax+ymin)/2.0);
-							switch(axis.TickPos()) {
+							switch(a.TickPos()) {
 							case 0: p->drawLine(x1,ypos-10,x1,ypos); break;
 							case 1: p->drawLine(x1,ypos,x1,ypos+10); break;
 							case 2: p->drawLine(x1,ypos-10,x1,ypos+10); break;
 							case 3: break;
 							}
 						}
-			
-						if (axis.MajorGridEnabled()) {
-							p->setPen(QPen(axis.majorGridColor(),axis.majorGridWidth(),axis.MajorGridType()));
+
+						if (a.MajorGridEnabled()) {
+							p->setPen(QPen(a.majorGridColor(),a.majorGridWidth(),a.MajorGridType()));
 							p->drawLine(x1,ymin,x1,ymax);
 							p->setPen(Qt::SolidLine);
 						}
@@ -585,14 +612,14 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 						y2 = ymax-(i+1)*(i+1)*(ymax-ymin)/(t*t);
 						break;
 					}
-	
+
 					if(y1<=ymax+1 && y1>=ymin-1) { // major tics
-						p->setPen(QPen(axis.TickColor(),axis.majorTickWidth()));
+						p->setPen(QPen(a.TickColor(),a.majorTickWidth()));
 						if(k==1) {	// y
 							int xpos = xmin;
 							if(pos)
 								xpos = (int) ((xmax+xmin)/2.0);
-							switch(axis.TickPos()) {
+							switch(a.TickPos()) {
 							case 0: p->drawLine(xpos-10,y1,xpos,y1); break;
 							case 1: p->drawLine(xpos,y1,xpos+10,y1); break;
 							case 2: p->drawLine(xpos-10,y1,xpos+10,y1); break;
@@ -603,24 +630,24 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 							int xpos = xmax;
 							if(pos)
 								xpos = (int) ((xmax+xmin)/2.0);
-							switch(axis.TickPos()) {
+							switch(a.TickPos()) {
 							case 0: p->drawLine(xpos,y1,xpos+10,y1); break;
 							case 1: p->drawLine(xpos-10,y1,xpos,y1); break;
 							case 2: p->drawLine(xpos-10,y1,xpos+10,y1); break;
 							case 3: break;
 							}
 						}
-						if (axis.MajorGridEnabled()) {
-							p->setPen(QPen(axis.majorGridColor(),axis.majorGridWidth(),axis.MajorGridType()));
+						if (a.MajorGridEnabled()) {
+							p->setPen(QPen(a.majorGridColor(),a.majorGridWidth(),a.MajorGridType()));
 							p->drawLine(xmin,y1,xmax,y1);
 							p->setPen(Qt::SolidLine);
 						}
 					}
-				}	
+				}
 
-				if (axis.tickLabelEnabled() && graphlist->Number() > 0) {		// Numbers
-					QColor c = axis.TickLabelColor();
-					QFont f = axis.TickLabelFont();
+				if (a.tickLabelEnabled() && graphlist->Number() > 0) {		// Numbers
+					QColor c = a.TickLabelColor();
+					QFont f = a.TickLabelFont();
 					double dx = max-min, value=0;
 
 					switch(scale) {
@@ -631,23 +658,23 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 					}
 
 					// round small values
-					int prec = axis.TickLabelPrecision();
+					int prec = a.TickLabelPrecision();
 					if(scale == LINEAR && prec>0)
 							value = dx*round(value*pow(10.0,prec)/dx)/pow(10.0,prec);
 
 					// apply scale and shift value
-					value = value*axis.Scaling()+axis.Shift();
+					value = value*a.Scaling()+a.Shift();
 
-					TFormat atlf = axis.TickLabelFormat();
-					QString label = TicLabel(atlf, prec, axis.DateTimeFormat(), value);
+					TFormat atlf = a.TickLabelFormat();
+					QString label = TicLabel(atlf, prec, a.DateTimeFormat(), value);
 
 					// apply prefix & suffix
-					label.prepend(axis.TickLabelPrefix());
-					label.append(axis.TickLabelSuffix());
+					label.prepend(a.TickLabelPrefix());
+					label.append(a.TickLabelSuffix());
 
 					// draw tic label
 					QFontMetrics fm(f);
-					int gap = (int)(axis.TickLabelPosition());
+					int gap = (int)(a.TickLabelPosition());
 
 					switch(k) {
 					case 0:	y1 = ymax + gap + (int)(size.Y()*fm.ascent()/2); break;
@@ -655,7 +682,7 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 					case 2:	x1 = xmax + gap + (int)(size.X()*fm.ascent()); break;
 					case 3:	y1 = ymin - gap - (int)(size.Y()*fm.ascent()/2); break;
 					}
-					
+
 					if(pos) {
 						switch(k) {
 						case 0:	y1 += (int) ((ymin-ymax)/2.0); break;
@@ -664,15 +691,15 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 						case 3:	y1 += (int) ((ymax-ymin)/2.0); break;
 						}
 					}
-	
+
 					p->save();
 					p->translate(x1,y1);
-					p->rotate(axis.TickLabelRotation());
+					p->rotate(a.TickLabelRotation());
 					f.setPointSize((int)(f.pointSize()*size.X()));	// resize tic label
 					if (atlf == AUTO || atlf == NORMAL || atlf == SCIENTIFIC) {
 						p->setPen(c);
 						p->setFont(f);
-						
+
 						if(axistype == 0) {
 							if(x1<=xmax+1 && x1>=xmin-1)
 								p->drawText(-fm.width(label)/2,fm.ascent()/2,label);
@@ -686,7 +713,7 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 						QSimpleRichText *richtext = new QSimpleRichText(label,f);
 						QColorGroup cg;
 						cg.setColor(QColorGroup::Text,c);
-	
+
 						if(axistype == 0) {
 							if(x1<=xmax+1 && x1>=xmin-1)
 								richtext->draw(p,-richtext->width()/4, -fm.ascent()/2,QRect(),cg);
@@ -695,31 +722,32 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 							if(y1<=ymax+1 && y1>=ymin-1)
 								richtext->draw(p,-richtext->width(),(int)(-richtext->height()/2.0-1), QRect(),cg);
 						}
+						delete richtext;
 					}
 					p->restore();
 				}
 
-				if (axis.MinorTicksEnabled() && i != t ) {	// Minor Ticks
-					for (int j=1;j <= axis.MinorTicks();j++) {
+				if (a.MinorTicksEnabled() && i != t ) {	// Minor Ticks
+					for (int j=1;j <= a.MinorTicks();j++) {
 						if(scale == LOG10 && j > 8)	// maximal 8 minor ticks possible
 							break;
 
 						if(axistype == 0) {	// X Minor Ticks
 							int x=0;
 							if(scale == LINEAR)
-								x = x1+j*(x2-x1)/(axis.MinorTicks()+1);
+								x = x1+j*(x2-x1)/(a.MinorTicks()+1);
 							else if (scale == LOG10)
 								x = (int)(x1+(x2-x1)*log10((double)(j+1)));
 							// TODO : SQRT minor tics ?
 							// other scales have no minor tics
-	
+
 							if(x<=xmax+1 && x>=xmin-1) { // minor tics
-								p->setPen(QPen(axis.TickColor(),axis.minorTickWidth()));
+								p->setPen(QPen(a.TickColor(),a.minorTickWidth()));
 								if(k==0) {	// x
 									int ypos = ymax;
 									if(pos)
 										ypos = (int) ((ymax+ymin)/2.0);
-									switch(axis.TickPos()) {
+									switch(a.TickPos()) {
 									case 0: p->drawLine(x,ypos,x,ypos+5); break;
 									case 1: p->drawLine(x,ypos-5,x,ypos); break;
 									case 2: p->drawLine(x,ypos-5,x,ypos+5); break;
@@ -730,16 +758,16 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 									int ypos = ymin;
 									if(pos)
 										ypos = (int) ((ymax+ymin)/2.0);
-									switch(axis.TickPos()) {
+									switch(a.TickPos()) {
 									case 0: p->drawLine(x,ypos-5,x,ypos); break;
 									case 1: p->drawLine(x,ypos,x,ypos+5); break;
 									case 2: p->drawLine(x,ypos-5,x,ypos+5); break;
 									case 3: break;
 									}
 								}
-								if (axis.MinorGridEnabled() && j != axis.MinorTicks()+1) {
-									p->setPen(QPen(axis.minorGridColor(),
-										axis.minorGridWidth(),axis.MinorGridType()));
+								if (a.MinorGridEnabled() && j != a.MinorTicks()+1) {
+									p->setPen(QPen(a.minorGridColor(),
+										a.minorGridWidth(),a.MinorGridType()));
 									p->drawLine(x,ymin,x,ymax);
 									p->setPen(Qt::SolidLine);
 								}
@@ -748,18 +776,18 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 						else {	// Y Minor Ticks
 							int y=0;
 							if(scale == LINEAR)
-								y = y1+j*(y2-y1)/(axis.MinorTicks()+1);
+								y = y1+j*(y2-y1)/(a.MinorTicks()+1);
 							else if (scale == LOG10)
 								y = (int)(y1+(double)(y2-y1)*log10((double)(j+1)));
 							// all other scales have minor tics = 0
-	
+
 							if(y<=ymax+1 && y>=ymin-1) { // minor tics
-								p->setPen(QPen(axis.TickColor(),axis.minorTickWidth()));
+								p->setPen(QPen(a.TickColor(),a.minorTickWidth()));
 								if(k==1) {	// y
 									int xpos = xmin;
 									if(pos)
 										xpos = (int) ((xmax+xmin)/2.0);
-									switch(axis.TickPos()) {
+									switch(a.TickPos()) {
 									case 0: p->drawLine(xpos-5,y,xpos,y); break;
 									case 1: p->drawLine(xpos,y,xpos+5,y); break;
 									case 2: p->drawLine(xpos-5,y,xpos+5,y); break;
@@ -770,16 +798,16 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 									int xpos = xmax;
 									if(pos)
 										xpos = (int) ((xmax+xmin)/2.0);
-									switch(axis.TickPos()) {
+									switch(a.TickPos()) {
 									case 0: p->drawLine(xpos,y,xpos+5,y); break;
 									case 1: p->drawLine(xpos-5,y,xpos,y); break;
 									case 2: p->drawLine(xpos-5,y,xpos+5,y); break;
 									case 3: break;
 									}
 								}
-								if (axis.MinorGridEnabled() && j != axis.MinorTicks()+1) {
-									p->setPen(QPen(axis.minorGridColor(),
-										axis.minorGridWidth(),axis.MinorGridType()));
+								if (a.MinorGridEnabled() && j != a.MinorTicks()+1) {
+									p->setPen(QPen(a.minorGridColor(),
+										a.minorGridWidth(),a.MinorGridType()));
 									p->drawLine(xmin,y,xmax,y);
 								}
 								p->setPen(Qt::SolidLine);
@@ -791,7 +819,7 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 		}
 		else {		// Tic Type INCREMENT
 			// use axis Major Ticks as increment
-			double inc = axis.MajorTicks();
+			double inc = a.MajorTicks();
 			double dx=max-min;
 //			kdDebug()<<"	DX = "<<dx<<endl;
 			if(inc == -1)	// auto tics
@@ -813,12 +841,12 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 //					kdDebug()<<"	VALUE : "<<value<<endl;
 //					kdDebug()<<"	X1 : "<<x1<<endl;
 					if(x1<=xmax+1 && x1>=xmin-1) {
-						p->setPen(QPen(axis.TickColor(),axis.majorTickWidth()));
+						p->setPen(QPen(a.TickColor(),a.majorTickWidth()));
 						if(k==0) {	// x
 							int ypos = ymax;
 							if(pos)
 								ypos = (int) ((ymax+ymin)/2.0);
-							switch(axis.TickPos()) {
+							switch(a.TickPos()) {
 							case 0: p->drawLine(x1,ypos,x1,ypos+10); break;
 							case 1: p->drawLine(x1,ypos-10,x1,ypos); break;
 							case 2: p->drawLine(x1,ypos-10,x1,ypos+10); break;
@@ -829,16 +857,16 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 							int ypos = ymin;
 							if(pos)
 								ypos = (int) ((ymax+ymin)/2.0);
-							switch(axis.TickPos()) {
+							switch(a.TickPos()) {
 							case 0: p->drawLine(x1,ypos-10,x1,ypos); break;
 							case 1: p->drawLine(x1,ypos,x1,ypos+10); break;
 							case 2: p->drawLine(x1,ypos-10,x1,ypos+10); break;
 							case 3: break;
 							}
 						}
-			
-						if (axis.MajorGridEnabled()) {
-							p->setPen(QPen(axis.majorGridColor(),axis.majorGridWidth(),axis.MajorGridType()));
+
+						if (a.MajorGridEnabled()) {
+							p->setPen(QPen(a.majorGridColor(),a.majorGridWidth(),a.MajorGridType()));
 							p->drawLine(x1,ymin,x1,ymax);
 							p->setPen(Qt::SolidLine);
 						}
@@ -848,14 +876,14 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 					y1 = ymax-(int)((value-min)*(ymax-ymin)/dx);
 //					kdDebug()<<"	VALUE : "<<value<<endl;
 //					kdDebug()<<"	Y1 : "<<y1<<endl;
-	
+
 					if(y1<=ymax+1 && y1>=ymin-1) { // major tics
-						p->setPen(QPen(axis.TickColor(),axis.majorTickWidth()));
+						p->setPen(QPen(a.TickColor(),a.majorTickWidth()));
 						if(k==1) {	// y
 							int xpos = xmin;
 							if(pos)
 								xpos = (int) ((xmax+xmin)/2.0);
-							switch(axis.TickPos()) {
+							switch(a.TickPos()) {
 							case 0: p->drawLine(xpos-10,y1,xpos,y1); break;
 							case 1: p->drawLine(xpos,y1,xpos+10,y1); break;
 							case 2: p->drawLine(xpos-10,y1,xpos+10,y1); break;
@@ -866,51 +894,51 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 							int xpos = xmax;
 							if(pos)
 								xpos = (int) ((xmax+xmin)/2.0);
-							switch(axis.TickPos()) {
+							switch(a.TickPos()) {
 							case 0: p->drawLine(xpos,y1,xpos+10,y1); break;
 							case 1: p->drawLine(xpos-10,y1,xpos,y1); break;
 							case 2: p->drawLine(xpos-10,y1,xpos+10,y1); break;
 							case 3: break;
 							}
 						}
-						if (axis.MajorGridEnabled()) {
-							p->setPen(QPen(axis.majorGridColor(),axis.majorGridWidth(),axis.MajorGridType()));
+						if (a.MajorGridEnabled()) {
+							p->setPen(QPen(a.majorGridColor(),a.majorGridWidth(),a.MajorGridType()));
 							p->drawLine(xmin,y1,xmax,y1);
 							p->setPen(Qt::SolidLine);
 						}
 					}
 				}
 
-				if (axis.tickLabelEnabled() && graphlist->Number() > 0) {		// Numbers
-					QColor c = axis.TickLabelColor();
-					QFont f = axis.TickLabelFont();
-					
+				if (a.tickLabelEnabled() && graphlist->Number() > 0) {		// Numbers
+					QColor c = a.TickLabelColor();
+					QFont f = a.TickLabelFont();
+
 					// round small values
-					int prec = axis.TickLabelPrecision();
+					int prec = a.TickLabelPrecision();
 					if(prec>0)
 						value = inc*round(value*pow(10.0,prec)/inc)/pow(10.0,prec);
-					
+
 					// apply scale and shift value
-					value = value*axis.Scaling()+axis.Shift();
-	
-					TFormat atlf = axis.TickLabelFormat();
-					QString label = TicLabel(atlf, prec, axis.DateTimeFormat(), value);
-	
+					value = value*a.Scaling()+a.Shift();
+
+					TFormat atlf = a.TickLabelFormat();
+					QString label = TicLabel(atlf, prec, a.DateTimeFormat(), value);
+
 					// apply prefix & suffix
-					label.prepend(axis.TickLabelPrefix());
-					label.append(axis.TickLabelSuffix());
-	
+					label.prepend(a.TickLabelPrefix());
+					label.append(a.TickLabelSuffix());
+
 					// draw tic label
 					QFontMetrics fm(f);
-					int gap = (int)(axis.TickLabelPosition());
-					
+					int gap = (int)(a.TickLabelPosition());
+
 					switch(k) {
 					case 0:	y1=ymax+gap+(int)(size.Y()*fm.ascent()/2); break;
 					case 1:	x1=xmin-gap-(int)(size.X()*fm.ascent()); break;
 					case 2:	x1=xmax+gap+(int)(size.X()*fm.ascent()); break;
 					case 3:	y1=ymin-gap-(int)(size.Y()*fm.ascent()/2); break;
 					}
-					
+
 					if(pos) {
 						switch(k) {
 						case 0:	y1 += (int) ((ymin-ymax)/2.0); break;
@@ -919,14 +947,14 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 						case 3:	y1 += (int) ((ymax-ymin)/2.0); break;
 						}
 					}
-					
+
 					p->save();
 					p->translate(x1,y1);
-					p->rotate(axis.TickLabelRotation());
+					p->rotate(a.TickLabelRotation());
 					if (atlf == AUTO || atlf == NORMAL || atlf == SCIENTIFIC) {
 						p->setPen(c);
 						p->setFont(f);
-						
+
 						if(axistype == 0) {
 							if(x1<=xmax+1 && x1>=xmin)
 								p->drawText(-fm.width(label)/2,fm.ascent()/2,label);
@@ -940,7 +968,7 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 						QSimpleRichText *richtext = new QSimpleRichText(label,f);
 						QColorGroup cg;
 						cg.setColor(QColorGroup::Text,c);
-	
+
 						if(axistype == 0) {
 							if(x1<=xmax+1 && x1>=xmin)
 								richtext->draw(p,-richtext->width()/4, -fm.ascent()/2,QRect(),cg);
@@ -949,12 +977,13 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 							if(y1<=ymax+1 && y1>=ymin-1)
 								richtext->draw(p,-richtext->width(),(int)(-richtext->height()/2.0-1), QRect(),cg);
 						}
+						delete richtext;
 					}
 					p->restore();
 				}
-				
-				if (axis.MinorTicksEnabled()) {	// Minor Ticks
-					int tt = axis.MinorTicks()+1;
+
+				if (a.MinorTicksEnabled()) {	// Minor Ticks
+					int tt = a.MinorTicks()+1;
 					for (int j=1;j < tt;j++) {
 						if(axistype == 0) {	// X Minor Ticks
 							int x=0;
@@ -965,14 +994,14 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 							// TODO : SQRT minor tics ?
 //							kdDebug()<<"	X ("<<j<<")  ="<<x<<endl;
 							// other scales have no minor tics
-	
+
 							if(x<=xmax+1 && x>=xmin-1) { // minor tics
-								p->setPen(QPen(axis.TickColor(),axis.minorTickWidth()));
+								p->setPen(QPen(a.TickColor(),a.minorTickWidth()));
 								if(k==0) {	// x
 									int ypos = ymax;
 									if(pos)
 										ypos = (int) ((ymax+ymin)/2.0);
-									switch(axis.TickPos()) {
+									switch(a.TickPos()) {
 									case 0: p->drawLine(x,ypos,x,ypos+5); break;
 									case 1: p->drawLine(x,ypos-5,x,ypos); break;
 									case 2: p->drawLine(x,ypos-5,x,ypos+5); break;
@@ -983,16 +1012,16 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 									int ypos = ymin;
 									if(pos)
 										ypos = (int) ((ymax+ymin)/2.0);
-									switch(axis.TickPos()) {
+									switch(a.TickPos()) {
 									case 0: p->drawLine(x,ypos-5,x,ypos); break;
 									case 1: p->drawLine(x,ypos,x,ypos+5); break;
 									case 2: p->drawLine(x,ypos-5,x,ypos+5); break;
 									case 3: break;
 									}
 								}
-								if (axis.MinorGridEnabled() && j != axis.MinorTicks()+1) {
-									p->setPen(QPen(axis.minorGridColor(),
-										axis.minorGridWidth(),axis.MinorGridType()));
+								if (a.MinorGridEnabled() && j != a.MinorTicks()+1) {
+									p->setPen(QPen(a.minorGridColor(),
+										a.minorGridWidth(),a.MinorGridType()));
 									p->drawLine(x,ymin,x,ymax);
 									p->setPen(Qt::SolidLine);
 								}
@@ -1006,14 +1035,14 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 							//	y=(int)(y1+(y2-y1)*log10((double)(j)));
 							// all other scales have minor tics = 0
 //							kdDebug()<<"	Y ("<<j<<")  ="<<y<<endl;
-	
+
 							if(y<=ymax+1 && y>=ymin-1) { // minor tics
-								p->setPen(QPen(axis.TickColor(),axis.minorTickWidth()));
+								p->setPen(QPen(a.TickColor(),a.minorTickWidth()));
 								if(k==1) {	// y
 									int xpos=xmin;
 									if(pos)
 										xpos = (int) ((xmax+xmin)/2.0);
-									switch(axis.TickPos()) {
+									switch(a.TickPos()) {
 									case 0: p->drawLine(xpos-5,y,xpos,y); break;
 									case 1: p->drawLine(xpos,y,xpos+5,y); break;
 									case 2: p->drawLine(xpos-5,y,xpos+5,y); break;
@@ -1024,16 +1053,16 @@ void Plot2D::drawAxesTicks(QPainter *p, int w, int h, Axis axis, int k) {
 									int xpos=xmax;
 									if(pos)
 										xpos = (int) ((xmax+xmin)/2.0);
-									switch(axis.TickPos()) {
+									switch(a.TickPos()) {
 									case 0: p->drawLine(xpos,y,xpos+5,y); break;
 									case 1: p->drawLine(xpos-5,y,xpos,y); break;
 									case 2: p->drawLine(xpos-5,y,xpos+5,y); break;
 									case 3: break;
 									}
 								}
-								if (axis.MinorGridEnabled() && j != axis.MinorTicks()+1) {
-									p->setPen(QPen(axis.minorGridColor(),
-										axis.minorGridWidth(),axis.MinorGridType()));
+								if (a.MinorGridEnabled() && j != a.MinorTicks()+1) {
+									p->setPen(QPen(a.minorGridColor(),
+										a.minorGridWidth(),a.MinorGridType()));
 									p->drawLine(xmin,y,xmax,y);
 								}
 								p->setPen(Qt::SolidLine);
@@ -1060,42 +1089,43 @@ void Plot2D::drawAxes(QPainter *p,int w, int h) {
 
 	//AxesLabel
 //	kdDebug()<<"	drawing axis label"<<endl;
-	Label *label = axis[3].getLabel();	// x2
-	if (label->X()==0 && label->Y()==0)	// default
-		label->setPosition((xmin+(xmax-xmin)/2)/(double)w,
+	Label *x2label = axis[3].getLabel();	// x2
+	if (x2label->X()==0 && x2label->Y()==0)	// default
+		x2label->setPosition((xmin+(xmax-xmin)/2)/(double)w,
 			(ymin-(unit+3*numunit2)*axis[3].MajorTicksEnabled()-2*unit)/(double)h);
 	if (axis[3].Enabled())
-		label->draw(worksheet,p,position,size,w,h,0);
-	
-	label = axis[0].getLabel();		// x
-	if (label->X()==0 && label->Y()==0)	// default
-		label->setPosition((xmin+(xmax-xmin)/2)/(double)w,
+		x2label->draw(worksheet,p,position,size,w,h,0);
+
+	Label *xlabel = axis[0].getLabel();		// x
+	if (xlabel->X()==0 && xlabel->Y()==0)	// default
+		xlabel->setPosition((xmin+(xmax-xmin)/2)/(double)w,
 			(ymax+(unit+numunit2)*axis[0].MajorTicksEnabled())/(double)h);
 	if (axis[0].Enabled())
-		label->draw(worksheet,p,position,size,w,h,0);
-	
-	label = axis[1].getLabel();		// y
-	if (label->X()==0 && label->Y()==0)	// default
-		label->setPosition(0.01, (ymin+(ymax-ymin)/2)/(double)h);
+		xlabel->draw(worksheet,p,position,size,w,h,0);
+
+	Label *ylabel = axis[1].getLabel();		// y
+	if (ylabel->X()==0 && ylabel->Y()==0)	// default
+		ylabel->setPosition(0.01, (ymin+(ymax-ymin)/2)/(double)h);
 	if (axis[1].Enabled()) {
 		p->save();
-		label->draw(worksheet,p,position,size,w,h,270);
+		ylabel->draw(worksheet,p,position,size,w,h,270);
 		p->restore();
 	}
-	
-	label = axis[2].getLabel();		// y2
-	if (label->X()==0 && label->Y()==0)	// default
-		label->setPosition((xmax+(2*unit+numunit)*axis[2].MajorTicksEnabled())/(double)w,
+
+	Label *y2label = axis[2].getLabel();		// y2
+	if (y2label->X()==0 && y2label->Y()==0)	// default
+		y2label->setPosition((xmax+(2*unit+numunit)*axis[2].MajorTicksEnabled())/(double)w,
 			(ymin+(ymax-ymin)/2)/(double)h);
 	if (axis[2].Enabled()) {
 		p->save();
-		label->draw(worksheet,p,position,size,w,h,270);
+		y2label->draw(worksheet,p,position,size,w,h,270);
 		p->restore();
 	}
 
 	// axes tics and grid
 	for (int k=0;k<4;k++)
 		drawAxesTicks(p, w, h, axis[k], k);
+	kdDebug()<<"Plot2D::drawAxes() DONE"<<endl;
 }
 
 void Plot2D::saveAxes(QTextStream *t) {
@@ -1110,12 +1140,12 @@ void Plot2D::openAxes(QTextStream *t, int version) {
 
 void Plot2D::saveXML(QDomDocument doc, QDomElement plottag) {
 	QDomElement tag;
-	
+
 	for (int i = 0; i < 4; i++) {
 		tag = axis[i].saveXML(doc,i);
    		plottag.appendChild( tag );
 	}
-	
+
 	if(type == PSURFACE)
 		((Plot2DSurface *)this)->saveSurfaceXML(doc,plottag);
 }
