@@ -3,13 +3,14 @@
 #include <iostream>
 #include <klocale.h>
 #include <kdebug.h>
+#include <kmessagebox.h>
 #include "Plot3D.h"
 
 using namespace std;
 
 //! general 3D Plot class
 Plot3D::Plot3D(Worksheet *p)
-	: Plot(p) 
+	: Plot(p)
 {
 	QFont font = p->getMainWin()->defaultFont();
 	font.setPointSize((int)(0.7*font.pointSize()));	// for axes label
@@ -39,6 +40,17 @@ Plot3D::Plot3D(Worksheet *p)
 	for (int i=0;i<12;i++) {
 		axis[i].setTickLabelFont(font);
 	}
+
+	renderstyle=0;
+}
+
+Plot3D::~Plot3D() {
+	delete graphlist;
+
+	delete title;
+	delete markx;
+	delete marky;
+	delete region;
 }
 
 QStringList Plot3D::Info() {
@@ -51,8 +63,8 @@ QStringList Plot3D::Info() {
 		s<<QString("yes");
 	else
 		s<<QString("no");
-	s<<bgcolor.name();
-	s<<gbgcolor.name();
+	s<<bgcolor.color().name();
+	s<<gbgcolor.color().name();
 
 	return s;
 }
@@ -125,11 +137,11 @@ void Plot3D::setBorder(int item, bool on) {
 
 void Plot3D::draw(QPainter *p,int w, int h) {
 	kdDebug()<<"Plot3D::draw() w/h : "<<w<<' '<<h<<endl;
-	
+
 	if(aspect_enabled) {	// set aspect ratio to 1
 		int wsize = (int) fmin(w,h);
 		w=h=wsize;
-	}	
+	}
 
 	int xmin = (int)(w*(size.X()*p1.X()+position.X()));
 	int xmax = (int)(w*(size.X()*p2.X()+position.X()));
@@ -160,8 +172,8 @@ void Plot3D::draw(QPainter *p,int w, int h) {
 		(xmax+xmin)/2,ymin-(ymax-ymin)/2,xmin,ymin);
 	p->drawPolygon(a);
 
-        // TODO : draw y baseline here (before every axis ?) -> see Plot2D.cc
-        // TODO : draw x baseline here (before every axis ?) -> see Plot2D.cc
+	// TODO : draw y baseline here (before every axis ?) -> see Plot2D.cc
+	// TODO : draw x baseline here (before every axis ?) -> see Plot2D.cc
 
 	// TODO
 	kdDebug()<<"PLOT3D : title->draw() pos:"<<position.X()<<' '<<position.Y()<<endl;
@@ -229,30 +241,28 @@ void Plot3D::drawCurves(QPainter *p, int w, int h) {
 	kdDebug()<<"width/height : "<<w<<'/'<<h<<endl;
 
 	for (unsigned int i=0; i < graphlist->Number() ; i++) {
-		kdDebug()<<"draw Graph "<<i+1<<endl;
-		if(graphlist->getGraph(i)->isShown() == false)
-			continue;
-		
+		kdDebug()<<"draw Graph "<<i<<endl;
+		if(graphlist->getGraph(i)->isShown() == false) continue;
+
 		double oldx=0, oldy=0;
-		double oldlinex=0, oldliney=0;
 		int N, NY=0, NX=0;
 		Style *style=0;
 		Symbol *symbol=0;
-		GRAPHType s = graphlist->getStruct(i);
-		Graph *graph=graphlist->getGraph(i);
+		GRAPHType gtype = graphlist->getType(i);
+		Graph *graph = graphlist->getGraph(i);
 		Point3D *d=0;
-		if (s == GRAPH3D) {
+		if (gtype == GRAPH3D) {
 			kdDebug()<<"GRAPH3D "<<endl;
 			Graph3D *g = graphlist->getGraph3D(i);
 
 			d = g->Data();
 			NX=g->NX();
 			NY=g->NY();
-			style =  g->getStyle();
+			kdDebug()<<"NX/NY "<<NX<<' '<<NY<<endl;
+			style = g->getStyle();
 			symbol = g->getSymbol();
-			kdDebug()<<" ... OK "<<endl;
 		}
-		else if (s == GRAPHM) {
+		else if (gtype == GRAPHM) {
 			GraphM *g = graphlist->getGraphM(i);
 
 			double *data = g->Data();
@@ -274,9 +284,87 @@ void Plot3D::drawCurves(QPainter *p, int w, int h) {
 		else
 			N=NX*NY;
 
-		int type = style->Type();
+		// calculate position matrix
+		Point *pos = new Point[NX*NY];
+		double x,y;
+		for(int index=0;index<NX*NY;index++) {
+			x = xmin + (d[index].X() - actrange[0].rMin()) *
+				(xmax-xmin)/(actrange[0].rMax() - actrange[0].rMin())
+				+ (xmax-xmin)/(2*(actrange[1].rMax() -
+				actrange[1].rMin()))*(d[index].Y()-actrange[1].rMin());
+			y = ymax - (d[index].Y() - actrange[1].rMin()) *
+				(ymax-ymin)/(actrange[1].rMax() - actrange[1].rMin())
+				+ (ymax-ymin)/(2*(actrange[1].rMax() -
+				actrange[1].rMin()))*(d[index].Y()-actrange[1].rMin())
+				- (d[index].Z()-actrange[2].rMin()) * (ymax-ymin)/(actrange[2].rMax()
+					- actrange[2].rMin());
+			pos[index].setPoint(x,y);
+		}
 
-		double *linex = new double[NX], *liney = new double[NX];	// NX is ok here
+		// do delaunay triangulation
+		if (style && style->Type() == LINESTYLE && N>3) {
+			kdDebug()<<"Doing Delaunay triangulation"<<endl;
+			QPen pen( style->Color(), style->Width(),(Qt::PenStyle) style->PenStyle() );
+			p->setPen(pen);
+			QPointArray a(100);	// maximum number of points for one region
+			FILE *data = fopen("/tmp/labplot-qhull","w+");
+			if(data == NULL) {
+				kdDebug()<<"Can't open temp file /tmp/labplot-qhull! Giving up calculation and drawing."<<endl;
+				break;
+			}
+
+			if(renderstyle == TRUE) {	// 3d	: use if dz>0 and selected
+				fprintf(data,"3\n%d\n",NX*NY);
+				for (int l=0;l<NX*NY;l++)
+					fprintf(data,"%g %g %g\n",d[l].X(),d[l].Y(),d[l].Z());
+			}
+			else {	// 2d 	: use if dz=0, also very nice for surfaces (projection)
+				fprintf(data,"2\n%d\n",NX*NY);
+				for (int l=0;l<NX*NY;l++)
+					fprintf(data,"%g %g\n",d[l].X(),d[l].Y());
+			}
+			fclose(data);
+
+			// call qdelaunay; filenames are very strict! dont use d, n, etc.
+			KProcess *proc = new KProcess;
+			*proc << "qdelaunay";
+			*proc << "s Qt Fv TI /tmp/labplot-qhull TO /tmp/labplot-qhull-out";
+
+			if( proc->start(KProcess::Block) == false) {
+				kdDebug()<<"COULD NOT FIND qdelaunay! Disable line style."<<endl;
+				// don't explain every time
+				// KMessageBox::error(worksheet->getMainWin(),i18n("Could not find qdelaunay!"));
+			}
+			else {
+				FILE *pdata = fopen("/tmp/labplot-qhull-out","r+");
+				int nr;	// number of regions
+				fscanf(pdata,"%d",&nr);
+				for(int i=0;i<nr;i++) {
+					int dim=0;
+					fscanf(pdata,"%d",&dim);
+					// printf("REGION HAS %d POINTS\n",dim);
+					if (dim>100) continue;		// should not happen
+
+					int nr_points=0, np;
+					for(int j=0;j<dim;j++) {
+						fscanf(pdata,"%d",&np);
+						a.setPoint(nr_points++,(int)pos[np].X(),(int)pos[np].Y());
+					}
+					a.resize(nr_points);
+					if (style->isFilled()) {	//filled
+						p->setBrush(QBrush(style->FillColor(),(Qt::BrushStyle)style->Brush()));
+						p->drawPolygon(a);
+					}
+					else
+						p->drawPolyline(a);
+				}
+			}
+			// remove tmp file names !
+			unlink("/tmp/labplot-qhull");
+			unlink("/tmp/labplot-qhull-out");
+		}
+
+		// other styles
 		for (int k=NY-1; k>=0;k--) {
 			if(worksheet->getMainWin()->speedMode()) {
 				int mod = (int) (NY/sqrt((double) worksheet->getMainWin()->speedModeValue()));
@@ -285,25 +373,17 @@ void Plot3D::drawCurves(QPainter *p, int w, int h) {
 			}
 			for(int j=NX-1 ;j>=0;j--) {
 				int index = j+k*NX;
-				if (d[index].Masked())
-					continue;
-				
+				if (d[index].Masked()) continue;
+
+				x = pos[index].X();
+				y = pos[index].Y();
+
 				if(worksheet->getMainWin()->speedMode()) {
 					int mod = (int) (NX/sqrt((double) worksheet->getMainWin()->speedModeValue()));
 					if(mod==0) mod=1;
 					if(j%mod != 0) continue;	// speed mode
 				}
 				// TODO : scales (log10,log2,ln,sqrt)
-				double x = xmin + (d[index].X() - actrange[0].rMin()) *
-					(xmax-xmin)/(actrange[0].rMax() - actrange[0].rMin())
-					+ (xmax-xmin)/(2*(actrange[1].rMax() -
-					actrange[1].rMin()))*(d[index].Y()-actrange[1].rMin());
-				double y = ymax - (d[index].Y() - actrange[1].rMin()) *
-					(ymax-ymin)/(actrange[1].rMax() - actrange[1].rMin())
-					+ (ymax-ymin)/(2*(actrange[1].rMax() -
-					actrange[1].rMin()))*(d[index].Y()-actrange[1].rMin())
-					- (d[index].Z()-actrange[2].rMin()) * (ymax-ymin)/(actrange[2].rMax()
-					  - actrange[2].rMin());
 
 				int xlen = xmax-xmin;
 				int ylen = ymax-ymin;
@@ -322,19 +402,11 @@ void Plot3D::drawCurves(QPainter *p, int w, int h) {
 						QPointArray a;
 						p->setBrush(style->FillColor());
 
-						if (type == 0) {
-//							if (k>0 && j<NX-1) {
-							if (k<NY-1 && j<NX-1) {
-								a.setPoints( 4, (int)oldlinex,(int)oldliney,(int)linex[j],(int)liney[j],
-										(int)x,(int)y,(int)oldx,(int)oldy);
-								p->drawPolygon(a);
-							}
-						}
-						else if (type == 2 || type == 3) {
+						if (style->Type() == STEPSSTYLE || style->Type() == BOXESSTYLE) {
 							a.setPoints( 4,(int)(x-3*xlen/4),(int)(y+ylen/4),(int)(x+xlen/4),(int)(y+ylen/4),
 									(int)(x+3*xlen/4),(int)(y-ylen/4),(int)(x-xlen/4),(int)(y-ylen/4));
 							p->drawPolygon(a);
-							if (type == 3) {
+							if (style->Type() == BOXESSTYLE) {
 								a.setPoints(4,(int)(x-3*xlen/4),(int)(y+ylen/4),(int)(x-3*xlen/4),
 									(int)(dropy+ylen/4),(int)(x+xlen/4),(int)(dropy+ylen/4),
 									(int)(x+xlen/4),(int)(y+ylen/4));
@@ -347,22 +419,13 @@ void Plot3D::drawCurves(QPainter *p, int w, int h) {
 						}
 					}
 					else {
-						if (type == 0) {
-//							if (k>0 && j<NX-1) {
-							if (k<NY-1 && j<NX-1) {
-								p->drawLine((int)oldlinex,(int)oldliney,(int)linex[j],(int)liney[j]);
-								p->drawLine((int)linex[j],(int)liney[j],(int)x,(int)y);
-								p->drawLine((int)x,(int)y,(int)oldx,(int)oldy);
-								p->drawLine((int)oldx,(int)oldy,(int)oldlinex,(int)oldliney);
-							}
-						}
-						else if (type == 2 || type == 3) {
+						if (style->Type() == STEPSSTYLE || style->Type() == BOXESSTYLE) {
 							p->drawLine((int)(x-3*xlen/4),(int)(y+ylen/4),(int)(x+xlen/4),(int)(y+ylen/4));
 							p->drawLine((int)(x+xlen/4),(int)(y+ylen/4),(int)(x+3*xlen/4),(int)(y-ylen/4));
 							p->drawLine((int)(x+3*xlen/4),(int)(y-ylen/4),(int)(x-xlen/4),(int)(y-ylen/4));
 							p->drawLine((int)(x-xlen/4),(int)(y-ylen/4),(int)(x-3*xlen/4),(int)(y+ylen/4));
 
-							if (type == 3) { // drop step lines;
+							if (style->Type() == BOXESSTYLE) { // drop step lines;
 								p->drawLine((int)(x-3*xlen/4),(int)(y+ylen/4), (int)(x-3*xlen/4),(int)(dropy+ylen/4));
 								p->drawLine((int)(x+xlen/4),(int)(y+ylen/4), (int)(x+xlen/4),(int)(dropy+ylen/4));
 								p->drawLine((int)(x+3*xlen/4),(int)(y-ylen/4), (int)(x+3*xlen/4),(int)(dropy-ylen/4));
@@ -377,20 +440,17 @@ void Plot3D::drawCurves(QPainter *p, int w, int h) {
 						}
 					}
 
-					if (type == 4)
+					if (style->Type() == IMPULSESSTYLE)
 						p->drawLine((int)x,(int)y,(int)x,(int)dropy);
 
 					symbol->draw(p,(int)x,(int)y);
 					graph->getAnnotateValues().draw(p,(int)x,(int)y,d[index].X(),d[index].Y(),d[index].Z());
 				}
 				oldx = x;oldy = y;
-				oldlinex=linex[j];
-				oldliney=liney[j];
-				linex[j]=x;
-				liney[j]=y;
 			}
 		}
 	}
+	kdDebug()<<"Plot3D::drawCurves() DONE"<<endl;
 }
 
 //! draw the axes. hide=1 : only front axes (others hidden by curves)
@@ -469,7 +529,7 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 	for (int k=start;k<4;k++) {
 		int xi[4]={(xmin+xmax)/2,xmin,xmin,(xmin+xmax)/2};
 		int yi1[4], yi2[4], ykna[4], yknb[4];
-		switch (axis[3*k].TickPos()) {	// major/minor tics 
+		switch (axis[3*k].TickPos()) {	// major/minor tics
 		case 0:
 			yi1[0]=ymax-(ymax-ymin)/2+10; yi1[1]=ymax; yi1[2]=ymin-10; yi1[3]=ymin-(ymax-ymin)/2-10;
 			yi2[0]=ymax-(ymax-ymin)/2; yi2[1]=ymax+10; yi2[2]=ymin; yi2[3]=ymin-(ymax-ymin)/2;
@@ -547,7 +607,7 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 
 				// major ticks
 				if(axis[3*k].TickPos()!=3) {
-					kdDebug()<<"DRAWING MAJOR TICKS"<<endl;
+//					kdDebug()<<"DRAWING MAJOR TICKS"<<endl;
 					p->setPen(QPen(axis[3*k].TickColor(),axis[3*k].majorTickWidth()));
 					p->drawLine(x1,yi1[k],x1,yi2[k]);
 				}
@@ -577,9 +637,9 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 					// scale and shift value
 					value = value*axis[3*k].Scaling()+axis[3*k].Shift();
 
-					QString label = TicLabel(atlf,axis[3*k].TickLabelPrecision(), 
+					QString label = TicLabel(atlf,axis[3*k].TickLabelPrecision(),
 						axis[3*k].DateTimeFormat(),value);
-						
+
 					// apply prefix & suffix
 					label.prepend(axis[3*k].TickLabelPrefix());
 					label.append(axis[3*k].TickLabelSuffix());
@@ -662,7 +722,7 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 		int xib[4]={(xmax+xmin)/2,xmax,xmax,xmax+(xmax-xmin)/2};
 		int xina[4]={xmin,xmin,xmax,(xmax+xmin)/2};
 		int xinb[4]={(xmax+xmin)/2,xmax,xmax+(xmax-xmin)/2,xmax+(xmax-xmin)/2};
-		
+
 		if (axis[3*k+2].MajorTicksEnabled() && axis[3*k+2].Enabled()) {
 			double min = actrange[2].rMin(), max = actrange[2].rMax();
 			TScale scale = axis[k].Scale();
@@ -678,18 +738,18 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 			if(t==-1)
 				t=autoTicks(min,max);
 			if(t==0) t=-1;
-			
+
 			for (int i=0;i <= t;i++) {
 				// TODO : use scale (see x)
 				int y1 = yi[k]+i*(ymax-ymin)/t;
 				int y2 = yi[k]+(i+1)*(ymax-ymin)/t;
 				int yia[4] = {ymin+i*(ymax-ymin)/t,y1,y1+(ymin-ymax)/2,y1};
-			
+
 				if (axis[3*k+2].TickPos()!=3) {
 					p->setPen(QPen(axis[3*k+2].TickColor(),axis[3*k+2].majorTickWidth()));
 					p->drawLine(xi1[k],y1,xi2[k],y1);
 				}
-				
+
 				if (axis[3*k+2].MajorGridEnabled()) {
 					p->setPen(QPen(axis[3*k+2].majorGridColor(),
 						axis[3*k+2].majorGridWidth(),axis[3*k+2].MajorGridType()));
@@ -701,7 +761,7 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 					QFont f = axis[3*k+2].TickLabelFont();
 					double dz = max-min;
 					int atlf = axis[3*k+2].TickLabelFormat();
-	
+
 					double value=0;
 					switch(scale) {
 						case LINEAR: value = min + (t-i)*dz/t; break;
@@ -713,7 +773,7 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 					}
 					// scale and shift value
 					value = value*axis[3*k+2].Scaling()+axis[3*k+2].Shift();
-	
+
 					QString label = TicLabel(atlf,axis[3*k+2].TickLabelPrecision(),
 							axis[3*k+2].DateTimeFormat(),value);
 
@@ -788,7 +848,7 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 			if(t==-1)
 				t=autoTicks(min,max);
 			if (t==0) t=-1;
-			
+
 			for (int i=0;i <= t;i++) {
 				// TODO : use scale (see x)
 				int y1 = yi[k]-i*(ymax-ymin)/(2*t);
@@ -814,12 +874,12 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 				int xia[4]={x1,x1,x1-(xmax-xmin),x1};
 				int xib[4]={x1+xmax-xmin,x1,x1,x1};
 				int yib[4]={y1,y1-ymax+ymin,y1,y1+ymax-ymin};
-				
+
 				if (axis[3*k+1].TickPos()!=3) {
 					p->setPen(QPen(axis[3*k+1].TickColor(),axis[3*k+1].majorTickWidth()));
 					p->drawLine(xi1[k],y1,xi2[k],y1);
 				}
-				
+
 				if (axis[3*k+1].MajorGridEnabled()) {
 					p->setPen(QPen(axis[3*k+1].majorGridColor(),
 						axis[3*k+1].majorGridWidth(),axis[3*k+1].MajorGridType()));
@@ -879,7 +939,7 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 						int xina[4]={x,x,x-(xmax-xmin),x};
 						int xinb[4]={x+xmax-xmin,x,x,x};
 						int yinb[4]={y,y-ymax+ymin,y,y+ymax-ymin};
-					
+
 						int xkna[4],xknb[4];
 						switch(axis[3*k+1].TickPos()) {
 						case 0:
@@ -895,7 +955,7 @@ void Plot3D::drawAxes(QPainter *p, int w, int h, bool hide) {
 							xknb[0]=xknb[1]=xknb[2]=xknb[3]=x+5;
 							break;
 						}
-					
+
 						if (axis[3*k+1].TickPos()!=3) {
 							p->drawLine(xkna[k],y,xknb[k],y);
 						}
