@@ -9,7 +9,7 @@ class Plot3D:public Plot {
 public:
 	Plot3D(Worksheet *p);
 	QStringList Info();
-	~Plot3D() {}
+	~Plot3D();
 	Axis *getAxis(int i) { return &axis[i]; }
 	void saveAxes(QTextStream *t);
 	void openAxes(QTextStream *t,int version);
@@ -24,8 +24,11 @@ public:
 	void setActRange(LRange* r,int i) {actrange[i]=*r;}
 	void setRanges(LRange* r) {range[0]=r[0];range[1]=r[1];range[2]=r[2];}
 	void setActRanges(LRange* r) {actrange[0]=r[0];actrange[1]=r[1];actrange[2]=r[2];}
+	bool RenderStyle() { return renderstyle; }
+	void setRenderStyle(bool v=true) { renderstyle=v; }
 private:
 	Axis axis[12];		// x, y, z, x2, y2, z2, x3, y3, z3, x4, y4, z4
+	bool renderstyle;	// 0: surface (2d delaunay), 1: hull (3d delaunay)
 };
 
 #endif // PLOT3D_H
