@@ -20,7 +20,7 @@ using namespace std;
 PlotQWT3D::PlotQWT3D(Worksheet *p)
 	: Plot(p)
 #ifdef HAVE_GL
-	, Qwt3D::SurfacePlot((QWidget *)p) 
+	, Qwt3D::SurfacePlot((QWidget *)p)
 #endif
 {
 	QFont font = p->getMainWin()->defaultFont();
@@ -59,7 +59,7 @@ PlotQWT3D::PlotQWT3D(Worksheet *p)
 	Qwt3D::RGBA rgb;
 
 	ifstream file((const char*)colorscale.local8Bit());
-	
+
 	if(file) {
 		while ( file ) {
 			file >> rgb.r >> rgb.g >> rgb.b;
@@ -107,6 +107,16 @@ PlotQWT3D::PlotQWT3D(Worksheet *p)
 #endif
 }
 
+PlotQWT3D::~PlotQWT3D() {
+	delete graphlist;
+
+	delete title;
+	delete markx;
+	delete marky;
+
+	delete region;
+}
+
 QStringList PlotQWT3D::Info() {
 	QStringList s;
 	s<<"QWT";
@@ -117,9 +127,9 @@ QStringList PlotQWT3D::Info() {
 		s<<QString("yes");
 	else
 		s<<QString("no");
-	s<<bgcolor.name();
-	s<<gbgcolor.name();
-	
+	s<<bgcolor.color().name();
+	s<<gbgcolor.color().name();
+
 	return s;
 }
 
@@ -158,33 +168,33 @@ void PlotQWT3D::draw(QPainter *p, int w, int h) {
 	kdDebug()<<"PlotQWT3D::draw() : w/h="<<w<<' '<<h<<endl;
 #ifdef HAVE_GL
 	resize(w,h);
-	
+
 	kdDebug()<<"PlotStyle = "<<plotstyle<<endl;
 	Qwt3D::Plot3D::setPlotStyle(plotstyle);
 	// TODO : Enrichments : Qwt3D::Plot3D::setPlotStyle(Bar(0.007,0.5));
-	 
+
 	// TODO : set style of legend too
 	kdDebug()<<"CoordinateStyle = "<<coordinatestyle<<endl;
 	Qwt3D::Plot3D::setCoordinateStyle(coordinatestyle);
 	kdDebug()<<"FloorStyle = "<<floorstyle<<endl;
 	Qwt3D::SurfacePlot::setFloorStyle(floorstyle);
 
-	QColor c = Background();
+	QColor c = Background().color();
 	setBackgroundColor(Qwt3D::RGBA(c.red()/255.0,c.green()/255.0,c.blue()/255.0));
-	c = graphBackground();
+	c = graphBackground().color();
 	setMeshColor(Qwt3D::RGBA(c.red()/255.0,c.green()/255.0,c.blue()/255.0));
 
 	// Title
 	// TODO : boxed, rotation, richtext ?
 	QString t = title->simpleTitle();
-	//kdDebug()<<"title = "<<t<<endl;	
+	kdDebug()<<"title = "<<t<<endl;
 	setTitle(t);
 	setTitlePosition(1.0-title->Y(),title->X());		// TODO : Qwt3D::Anchor
 	QFont f = title->Font();
 	setTitleFont(f.family(),f.pointSize(),f.weight(),f.italic());
 	c = title->Color();
 	setTitleColor(Qwt3D::RGBA(c.red()/255.0,c.green()/255.0,c.blue()/255.0));
-	
+
 	// set data color
 	Qwt3D::StandardColor *col = new Qwt3D::StandardColor(this);
 	col->setColorVector(cv);
@@ -199,10 +209,12 @@ void PlotQWT3D::draw(QPainter *p, int w, int h) {
 	Qwt3D::ColorLegend *l = Qwt3D::Plot3D::legend();
 	// set legend position
 	double lx = Plot::legend.X(), ly = 1.0-Plot::legend.Y();
-//	kdDebug()<<"Legend X/Y "<<lx<<'/'<<ly<<endl; 
+	kdDebug()<<"Legend X/Y "<<lx<<'/'<<ly<<endl;
 	// for LeftRight :
-	
-	l->setTitleString((graphlist->getGraphM(0))->getLabel()->simpleTitle());		// TODO : position ?
+
+	GraphM *graph = graphlist->getGraphM(0);
+	if(graph)
+		l->setTitleString(graph->getLabel()->simpleTitle());		// TODO : position ?
 	f = Plot::legend.Font();
 	l->setTitleFont(f.family(),f.pointSize(),f.weight(),f.italic());
 	//TODO : Top,Bottom,Left,Right
@@ -222,6 +234,7 @@ void PlotQWT3D::draw(QPainter *p, int w, int h) {
 		case LOG2 : case LN : case SQRT: case SX2: break;
 	}
 	l->setScale(scale);
+	// TODO : what if delta==0 ?
 	l->setLimits(Plot::Ranges()[2].rMin(),Plot::Ranges()[2].rMax());
 
 	drawCurves(p,w,h);
@@ -229,6 +242,7 @@ void PlotQWT3D::draw(QPainter *p, int w, int h) {
 	updateData();
 	updateGL();
 #endif
+	kdDebug()<<"PlotQWT3D::draw() DONE"<<endl;
 }
 
 void PlotQWT3D::drawCurves(QPainter *, int, int) {
@@ -239,18 +253,19 @@ void PlotQWT3D::drawCurves(QPainter *, int, int) {
 	double minz=actrange[2].rMin(), maxz=actrange[2].rMax();
 
 	int item=0;	// only one graph possible
-	if(graphlist->getGraph(item)->isShown() == false)
+	Graph *graph = graphlist->getGraph(item);
+	if(graph == 0 || graph->isShown() == false)
 		return;
 
 	//Style *style=0;
 	//Symbol *symbol=0;
-	GRAPHType s = graphlist->getStruct(item);
+	GRAPHType s = graphlist->getType(item);
 	LRange rx, ry, rz;
 	int rows, cols;
 	if(s == GRAPHM) {
 		GraphM *g = graphlist->getGraphM(item);
-		rx=g->Range(0);
-		ry=g->Range(1);
+		rx = g->Range(0);
+		ry = g->Range(1);
 		rz = g->Range(2);
 
 		double *data = g->Data();
@@ -263,6 +278,7 @@ void PlotQWT3D::drawCurves(QPainter *, int, int) {
 		kdDebug()<<"	PLOT min/max x y = "<<minx<<' '<<maxx<<' '<<miny<<' '<<maxy<<endl;
 
 		kdDebug()<<"	DATA ROWS/COLS :"<<rows<<' '<<cols<<endl;
+		kdDebug()<<"	REAL ROWS/COLS :"<<rows*(maxy-miny)/(ry.rMax()-ry.rMin())<<' '<<cols*(maxx-minx)/(rx.rMax()-rx.rMin())<<endl;
 		int rcols = (int)(cols*(maxx-minx)/(rx.rMax()-rx.rMin()));
 		int scols = (int)(cols*(minx-rx.rMin())/(rx.rMax()-rx.rMin()));
 		int rrows = (int)(rows*(maxy-miny)/(ry.rMax()-ry.rMin()));
@@ -326,6 +342,9 @@ void PlotQWT3D::drawCurves(QPainter *, int, int) {
 
 		// copy data
 		// TODO : zoom in 3d data
+//		kdDebug()<<"	FILLING DATA"<<endl;
+//		kdDebug()<<"	rrows="<<rrows<<"	rcols="<<rcols<<endl;
+//		kdDebug()<<"	srows="<<srows<<"	scols="<<scols<<endl;
 		for(int i=0;i<rrows;i++) {
 			for(int j=0;j<rcols;j++) {
 				if(i<abs(srows))
@@ -338,6 +357,7 @@ void PlotQWT3D::drawCurves(QPainter *, int, int) {
 					sdata[j][i]=Qwt3D::Triple(maxx,maxy,0);
 				else {
 					int item = j+(i+srows)*cols+scols;
+//					kdDebug()<<"i/j/item "<<i<<' '<<j<<' '<<item<<"	: x/y/z "<<data[item].X()<<' '<<data[item].Y()<<' '<<data[item].Z()<<endl;
 					sdata[j][i] = Qwt3D::Triple(data[item].X(),data[item].Y(),data[item].Z());
 				}
 			}
@@ -346,7 +366,7 @@ void PlotQWT3D::drawCurves(QPainter *, int, int) {
 		// load data into surface plot
 		loadFromData(sdata,rcols,rrows);
 
-		//TODO : convert for showing surface, etc. ??? 
+		//TODO : convert for showing surface, etc. ???
 		Qwt3D::Plot3D::setPlotStyle(Qwt3D::POINTS);
 	}
 	else
@@ -428,8 +448,8 @@ void PlotQWT3D::drawCurves(QPainter *, int, int) {
 	coordinates()->axes[Qwt3D::X4].setScale(scale);
 	switch(axis[1].Scale()) {
 		case LINEAR : scale = Qwt3D::LINEARSCALE; break;
-		case LOG10 : 
-			      scale = Qwt3D::LOG10SCALE; 
+		case LOG10 :
+			      scale = Qwt3D::LOG10SCALE;
 			      coordinates()->axes[Qwt3D::Y1].setLimits(log10(miny),log10(maxy));
 			      coordinates()->axes[Qwt3D::Y2].setLimits(log10(miny),log10(maxy));
 			      coordinates()->axes[Qwt3D::Y3].setLimits(log10(miny),log10(maxy));
@@ -442,9 +462,9 @@ void PlotQWT3D::drawCurves(QPainter *, int, int) {
 	coordinates()->axes[Qwt3D::Y3].setScale(scale);
 	coordinates()->axes[Qwt3D::Y4].setScale(scale);
 	switch(axis[2].Scale()) {
-		case LINEAR : scale = Qwt3D::LINEARSCALE; break;
-		case LOG10 : 
-			      scale = Qwt3D::LOG10SCALE; 
+		case LINEAR : 	scale = Qwt3D::LINEARSCALE; break;
+		case LOG10 :
+			      scale = Qwt3D::LOG10SCALE;
 			      coordinates()->axes[Qwt3D::Z1].setLimits(log10(minz),log10(maxz));
 			      coordinates()->axes[Qwt3D::Z2].setLimits(log10(minz),log10(maxz));
 			      coordinates()->axes[Qwt3D::Z3].setLimits(log10(minz),log10(maxz));
@@ -517,7 +537,7 @@ void PlotQWT3D::saveXML(QDomDocument doc,QDomElement plottag) {
 		tag = axis[i].saveXML(doc,i);
    		plottag.appendChild( tag );
 	}
-	
+
 #ifdef HAVE_GL
 	tag = doc.createElement( "PlotStyle" );
    	plottag.appendChild( tag );
@@ -531,7 +551,7 @@ void PlotQWT3D::saveXML(QDomDocument doc,QDomElement plottag) {
    	plottag.appendChild( tag );
   	t = doc.createTextNode( QString::number(floorstyle) );
     	tag.appendChild( t );
-	
+
 	QDomElement cvtag = doc.createElement( "ColorVector" );
 	plottag.appendChild( cvtag );
 	for(unsigned int i=0;i<cv.size();i++) {
@@ -563,11 +583,11 @@ void PlotQWT3D::openXML(QDomElement e) {
 		axis[e.attribute("id").toInt()].openXML(e.firstChild());
 #ifdef HAVE_GL
 	else if(e.tagName() == "PlotStyle")
-		plotstyle = (Qwt3D::PLOTSTYLE) e.text().toInt(); 
+		plotstyle = (Qwt3D::PLOTSTYLE) e.text().toInt();
 	else if(e.tagName() == "CoordinateStyle")
-		coordinatestyle = (Qwt3D::COORDSTYLE) e.text().toInt(); 
+		coordinatestyle = (Qwt3D::COORDSTYLE) e.text().toInt();
 	else if(e.tagName() == "FloorStyle")
-		floorstyle = (Qwt3D::FLOORSTYLE) e.text().toInt(); 
+		floorstyle = (Qwt3D::FLOORSTYLE) e.text().toInt();
 	if(e.tagName() == "ColorVector") {
 		QDomNode node = e.firstChild();
 		cv.clear();
@@ -584,10 +604,10 @@ void PlotQWT3D::openXML(QDomElement e) {
 		}
 	}
 	else if(e.tagName() == "AspectRatio")
-		aspect_ratio = e.text().toInt(); 
+		aspect_ratio = e.text().toInt();
 	else if(e.tagName() == "MouseDisabled")
-		mouse_disabled = (bool) e.text().toInt(); 
+		mouse_disabled = (bool) e.text().toInt();
 	else if(e.tagName() == "Resolution")
-		resolution = e.text().toInt(); 
+		resolution = e.text().toInt();
 #endif
 }
