@@ -8,7 +8,7 @@
 class PlotTernary:public Plot {
 public:
 	PlotTernary(Worksheet *p);
-	~PlotTernary() {}
+	~PlotTernary();
 	QStringList Info();
 	Axis *getAxis(int) { return &axis; }
 	void saveAxes(QTextStream *t);
