@@ -27,8 +27,8 @@ public:
 	void setCreated(QDateTime c) {created=c;}
 	QDateTime Modified() { return modified; }
 	void setModified(QDateTime m) {modified=m;}
-	QString Comment() { return comment; }
-	void setComment(QString c) {comment=c;}
+	QString Notes() { return notes; }
+	void setNotes(QString c) {notes=c;}
 private:
 	QString filename;
 	int version;
@@ -37,7 +37,7 @@ private:
 	QString author;
 	QDateTime created;
 	QDateTime modified;
-	QString comment;
+	QString notes;
 };
 
 #endif //PROJECT_H
