@@ -12,17 +12,17 @@ class PstoEditDialog: public Dialog
 {
 	Q_OBJECT
 public:
-	PstoEditDialog(class MainWin *mw, QString fn="out.pdf", int f=4, int s=5, double sc=1.0,
+	PstoEditDialog(MainWin *mw, QString fn=i18n("out.pdf"), int f=4, int s=5, double sc=1.0,
 		double r=0.0, const char *name=0);
 public slots:
 	void updateFilename(int index);
 	void selectFile();
-	void OK() { agree(); accept(); }
-	void agree();
+	void Apply() { apply_clicked(); accept(); }
 private:
-	class MainWin *mw;
 	KComboBox *format, *pagesize;
 	KLineEdit *filele, *scalele, *rotle;
+private slots:
+	void apply_clicked();
 };
 
 #endif //PSTOEDITDIALOG_H
