@@ -18,13 +18,13 @@
 extern "C" con constants[];
 extern "C" init arith_fncts[];
 
-SpreadsheetValuesDialog::SpreadsheetValuesDialog(MainWin *mw, QTable *t, const char *name)
-	: Dialog(mw, name), table(t)
+SpreadsheetValuesDialog::SpreadsheetValuesDialog(MainWin *m, QTable *t, const char *name)
+	: Dialog(m, name), table(t)
 {
 	setCaption(QString("Spreadsheet")+i18n(" : ")+QString(name));
 
 	QHBox *hb = new QHBox(vbox);
-	columnlabel = new QLabel(i18n("Changing Column ") + i18n(" of ") + mw->activeSpreadsheet()->Title() + QString(" : "),hb);
+	columnlabel = new QLabel("",hb);
 	hb = new QHBox(vbox);
 
 	// use selected range / max range
@@ -40,7 +40,7 @@ SpreadsheetValuesDialog::SpreadsheetValuesDialog(MainWin *mw, QTable *t, const c
 	new QLabel(i18n(" to "),hb);
 	bni = new KIntNumInput(max,hb);
 	bni->setRange(1,INF,1,false);
-	
+
 	hb = new QHBox(vbox);
 	new QLabel(i18n("Columns :"),hb);
 	colcb = new KComboBox(hb);
@@ -66,7 +66,7 @@ SpreadsheetValuesDialog::SpreadsheetValuesDialog(MainWin *mw, QTable *t, const c
 		concb->insertItem(tmp);
 	};
 	QObject::connect(concb,SIGNAL(activated(int)),SLOT(insertConstant(int)));
-	
+
 	hb = new QHBox(vbox);
 	new QLabel(i18n("Functions :"),hb);
 	selcb = new KComboBox(hb);
@@ -81,11 +81,11 @@ SpreadsheetValuesDialog::SpreadsheetValuesDialog(MainWin *mw, QTable *t, const c
 
 	hb = new QHBox(vbox);
 	new QLabel(i18n(" Expression (index : i, col(A,i) = col(A)) : "),hb);
-	
+
 	hb = new QHBox(vbox);
 	funcb = new KComboBox(hb);
 	funcb->setEditable(true);
-	
+
 	int col = table->currentColumn();
 	KConfig *config = mw->Config();
 	config->setGroup( "Spreadsheet" );
@@ -108,7 +108,7 @@ SpreadsheetValuesDialog::SpreadsheetValuesDialog(MainWin *mw, QTable *t, const c
 
 		if(!entry.isEmpty() && !expr_found)
 			funcb->insertItem(entry);
-        }
+	}
 
 	QObject::connect(ok,SIGNAL(clicked()),SLOT(ok_clicked()));
 	QObject::connect(apply,SIGNAL(clicked()),SLOT(apply_clicked()));
@@ -116,24 +116,24 @@ SpreadsheetValuesDialog::SpreadsheetValuesDialog(MainWin *mw, QTable *t, const c
 	save->hide();
 
 	updateDialog();
-	
+
 	setMinimumWidth(vbox->minimumSizeHint().width());
 	setMinimumHeight(gbox->minimumSizeHint().height()+vbox->minimumSizeHint().height());
 	resize(minimumSize());
 }
 
 void SpreadsheetValuesDialog::updateDialog() {
-	columnlabel->setText(i18n("Changing Column ") + s->columnTitle(table->currentColumn()) + i18n(" of ") + s->Title() + QString(" : "));
+	columnlabel->setText(i18n("Changing Column ")+s->columnTitle(table->currentColumn())+i18n(" of ")+s->Title()+QString(" : "));
 }
 
 void SpreadsheetValuesDialog::insertColumn(int i) {
 	QLineEdit *le = funcb->lineEdit();
 	QString text = le->text();
 	int pos = le->cursorPosition();
-	
+
 	if(i>MAX_COLS)
 		return;
-	
+
 	// col(A)
 	QString tmp("col()");
 	if(i<26)
@@ -167,7 +167,7 @@ void SpreadsheetValuesDialog::insertFunction(int i) {
 
 void SpreadsheetValuesDialog::apply_clicked() {
 	QString expr = funcb->currentText();
-		
+
 	int startRow = ani->value(), endRow = bni->value();
 
 	if(!expr.isEmpty())
