@@ -12,13 +12,19 @@ class SpreadsheetValuesDialog: public Dialog
 	Q_OBJECT
 public:
 	SpreadsheetValuesDialog(MainWin *mw, QTable *t, const char *name);
+	void updateDialog();
 public slots:
+	void insertColumn(int i);
+	void insertConstant(int i);
+	void insertFunction(int i);
+private:
+	QTable *table;
+	KIntNumInput *ani, *bni;
+	KComboBox *colcb, *concb, *selcb, *funcb;
+	QLabel *columnlabel;
+private slots:
 	void ok_clicked() { apply_clicked(); accept(); }
 	void apply_clicked();
-private:
-	MainWin *mw;
-	QTable *table;
-	KLineEdit  *ale, *ble, *exprle;
 };
 
 #endif //SPREADSHEETVALUESDIALOG_H
