@@ -14,7 +14,8 @@ Symbol::Symbol(SType t, QColor c, int s, FType f, QColor fc, int b)
 	size = s;
 	fill = f;
 	fillcolor = fc;
-	brush=b;
+	brush = b;
+	errorbar = new Errorbar();
 }
 
 void Symbol::save(QTextStream *t) {
@@ -65,6 +66,11 @@ QDomElement Symbol::saveXML(QDomDocument doc) {
 	t = doc.createTextNode( QString::number(brush) );
 	tag.appendChild( t );
 
+	if(errorbar) {
+		tag = errorbar->saveXML(doc);
+		symboltag.appendChild(tag);
+	}
+
 	return symboltag;
 }
 
@@ -78,14 +84,18 @@ void Symbol::openXML(QDomNode node) {
 			type = (SType) e.text().toInt();
 		else if(e.tagName() == "Color")
 			color = QColor(e.text());
-		if(e.tagName() == "Size")
+		else if(e.tagName() == "Size")
 			size = e.text().toInt();
-		if(e.tagName() == "Fill")
+		else if(e.tagName() == "Fill")
 			fill = (FType) e.text().toInt();
 		else if(e.tagName() == "FillColor")
 			fillcolor = QColor(e.text());
-		if(e.tagName() == "Brush")
+		else if(e.tagName() == "Brush")
 			brush = e.text().toInt();
+		else if(e.tagName() == "Errorbar") {
+			if(errorbar)
+				errorbar->openXML(e.firstChild());
+		}
 
 		node = node.nextSibling();
 	}
@@ -185,7 +195,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(4,X-size,Y+size, X+size,Y+size, X,Y-size, X-size,Y+size);
@@ -224,7 +234,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(4,X-size,Y-size,X+size,Y-size,X,Y+size,X-size,Y-size);
@@ -309,7 +319,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(5,X-size,Y, X,Y-size, X+size,Y, X,Y+size, X-size,Y);
@@ -356,7 +366,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(3,X-size,Y-size, X-size,Y+size, X+size,Y);
@@ -395,7 +405,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(3,X+size,Y-size, X+size,Y+size, X-size,Y);
@@ -434,7 +444,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(3,X-size,Y-size, X+size,Y-size, X+size,Y+size);
@@ -473,7 +483,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(3,X-size,Y+size, X+size,Y+size, X-size,Y-size);
@@ -511,7 +521,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			a.setPoints(3,X-size,Y-size,X-size,Y,X,Y-size);
 			break;
 		}
-		p->drawPolygon(a);	
+		p->drawPolygon(a);
 
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
@@ -551,7 +561,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(3,X-size,Y+size, X+size,Y+size, X+size,Y-size);
@@ -637,7 +647,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(4,X-size/2,Y+size, X+size/2,Y+size, X+size/2,Y-size,X-size/2,Y-size);
@@ -790,7 +800,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 				X+size,Y-size/2,X+size/2,Y,X+size,Y+size/2,X+3*size/4,Y+3*size/4);
 			break;
 		case FDLEFT:
-			a.setPoints(8,X-size,Y-size/2, X-3*size/4,Y-3*size/4, X+3*size/4,Y+3*size/4,X+size/2,Y+size, 
+			a.setPoints(8,X-size,Y-size/2, X-3*size/4,Y-3*size/4, X+3*size/4,Y+3*size/4,X+size/2,Y+size,
 				X,Y+size/2,X-size/2,Y+size, X-size,Y+size/2,X-size/2,Y);
 			break;
 		case FDRIGHT:
@@ -884,7 +894,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(6,X-size,Y-size/2, X-size,Y-size,X-size/2,Y-size, X+size,Y+size/2,X+size,Y+size,X+size/2,Y+size);
@@ -933,7 +943,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(16,X-size,Y+size,X-size/2,Y+size,X,Y+size/2,X+size/2,Y+size,X+size,Y+size,
@@ -974,7 +984,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(4,X-size,Y+size,X,Y-size,X+size,Y-size,X,Y+size);
@@ -1013,7 +1023,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(4,X,Y+size,X-size,Y-size,X,Y-size,X+size,Y+size);
@@ -1048,7 +1058,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 		case FDLEFT:
 			break;
 		}
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		p->drawPie(X-size,Y-size,2*size,2*size,8*180,16*180);
@@ -1082,7 +1092,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 		case FDLEFT:
 			break;
 		}
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		p->drawPie(X-size,Y-size,2*size,2*size,24*180,16*180);
@@ -1116,7 +1126,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(4,X,Y-size,X-size/2,Y,X,Y+size,X+size/2,Y);
@@ -1346,7 +1356,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(6,X-size,Y,X-size/2,Y-size,X+size/2,Y-size,X+size,Y,X+size/2,Y+size,X-size/2,Y+size);
@@ -1385,7 +1395,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(6,X-size,Y-size/2,X,Y-size,X+size,Y-size/2,X+size,Y+size/2,X,Y+size,X-size,Y+size/2);
@@ -1425,7 +1435,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(8,X,Y-size,X+size/4,Y-size/4,X+size,Y,X+size/4,Y+size/4,
@@ -1462,7 +1472,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(4,X,Y-size,X+size,Y+size,X,Y,X-size,Y+size);
@@ -1497,7 +1507,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(4,X-size,Y,X+size,Y-size,X,Y,X+size,Y+size);
@@ -1532,7 +1542,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(4,X,Y+size,X-size,Y-size,X,Y,X+size,Y-size);
@@ -1567,7 +1577,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(4,X+size,Y,X-size,Y+size,X,Y,X-size,Y-size);
@@ -1606,7 +1616,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(5,X,Y-size,X+size,Y,X+size,Y+size,X-size,Y+size,X-size,Y);
@@ -1645,7 +1655,7 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 			break;
 		}
 		p->drawPolygon(a);
-		
+
 		p->setPen(color);
 		p->setBrush(Qt::NoBrush);
 		a.setPoints(5,X-size,Y,X,Y-size,X+size,Y-size,X+size,Y+size,X,Y+size);
@@ -1730,6 +1740,6 @@ void Symbol::draw(QPainter *p, int X, int Y) {
 		p->drawPolygon(a);
 		break;
 	}
-	
+
 	p->setPen(QColor("black"));
 }
