@@ -12,12 +12,17 @@ class TitleDialog: public Dialog
 {
 	Q_OBJECT
 public:
-	TitleDialog(Worksheet *p, const char *name);
-private slots:
-	void apply_clicked();
-	void ok_clicked();
+	TitleDialog(MainWin *mw, const char *name);
+	void updateDialog();
+public slots:
+	void setLabel(Label *l) { title=l; rtw->setLabel(l); rtw->update(); }
+	Label *getLabel() { return rtw->getLabel(); }
+	int Apply() { return apply_clicked(); }
 private:
 	Label *title;
 	RichTextWidget *rtw;
+private slots:
+	void ok_clicked();
+	int apply_clicked();
 };
 #endif //TITLEDIALOG_H
