@@ -19,11 +19,11 @@
 #include "widgettype.h"
 #include "scale.h"
 
-#ifdef HAVE_UNDO
+/*#ifdef HAVE_UNDO
 extern "C" {
 #include "undo.h"
 }
-#endif
+#endif*/
 
 #define NR_PLOTS 16
 #define NR_OBJECTS 100
@@ -46,7 +46,7 @@ class Worksheet: public QWidget
 	Q_PROPERTY(bool title_enabled READ TitleEnabled WRITE setTitleEnabled)
 	Q_PROPERTY(bool timestamp_enabled READ TimeStampEnabled WRITE setTimeStampEnabled)
 	Q_PROPERTY(QDateTime timestamp READ TimeStamp WRITE setTimeStamp)
-	Q_PROPERTY(QColor background READ Background WRITE setBackground)
+	Q_PROPERTY(QBrush background READ Background WRITE setBackground)
 private:
 	MainWin *mw;					// reference to the main window (for plotlist & messages)
 	WidgetType widgettype;
@@ -57,7 +57,7 @@ private:
 	bool title_enabled;				//!< title enabled
 	QDateTime timestamp;			//!< time stamp
 	bool timestamp_enabled;		//!< timestamp enabled
-	QColor background;
+	QBrush background;
 	
 	Label *label[NR_OBJECTS];
 	Line *line[NR_OBJECTS];
@@ -85,18 +85,22 @@ private:
 	int object_index;	// index of moving object
 	int tmp_object_index;	// index when defining object
 	unsigned int api, nr_plots;	// active plot index and number of plots
+	bool draw_objects_first;	// draw objects in background
 public:
 	Worksheet(QWidget *parent, MainWin *mw, const char *name);
+	~Worksheet();
+//	static void* operator new(size_t size);
+//	static void operator delete(void *p);
 	void closeNow();
 	WidgetType getWidgetType() { return widgettype; }
 	QStringList Info();
 	MainWin *getMainWin() { return mw; }	// for project dialog
 	Plot *getPlot(int i) { return plot[i]; }	//!< get plot number i
 	void setPlot(int i,Plot *p) { plot[i] = p; }	//!< set plot number i
-#ifdef HAVE_UNDO
+/*#ifdef HAVE_UNDO
 	UNDO *getUndo();
 	void setUndo(UNDO *u);
-#endif
+#endif*/
 	void updatePixmap();
 	void New();
 	void save(QTextStream *t);
@@ -116,13 +120,13 @@ public:
 	void checkRanges(TScale scale, double *min, double *max);
 	double partRanges(TScale scale, double min, double max);
 public slots:
-	void Export(QString filename, QString format);								//!< export to filename with format
-	void ExportPS(QString filename);											//!< export to filename as PS
-	void ExportEPS(QString filename);											//!< export to filename as EPS
-	void ExportPDF(QString filename);											//!< export to filename as PDF
-	void ExportSVG(QString filename);											//!< export to filename as SVG
-	void ExportPIC(QString filename);											//!< export to filename as PIC
-	void Print(QString filename);												//!< print to filename
+	void Export(QString filename, QString format, int quality=-1);				//!< export to filename with format
+	void ExportPS(QString filename);							//!< export to filename as PS
+	void ExportEPS(QString filename);							//!< export to filename as EPS
+	void ExportPDF(QString filename);							//!< export to filename as PDF
+	void ExportSVG(QString filename);							//!< export to filename as SVG
+	void ExportPIC(QString filename);							//!< export to filename as PIC
+	void Print(QString filename);								//!< print to filename
 
 	// needed wrapper for QSA
 	Plot2DSimple* get2DPlot(int i);  				//!< get 2d simple plot number i
@@ -158,19 +162,21 @@ public slots:
 	LImage* getImage(int i) { return image[i]; }		//!< get image number i
 	void setImage(int i, LImage* im) { image[i]=im; }	//!< set image number i to im
 
-	QString Title() const { return title; }										//!< get title
-	void setTitle(QString t) { title = t.remove(QChar('&')); setCaption(title); updatePixmap(); }				//!< set title to t
-	bool TitleEnabled() const { return title_enabled; }							//!< title enabled ?
-	void enableTitle(bool e=true) { title_enabled = e; updatePixmap(); }			//!< enable title	
+	QString Title() const { return title; }
+	void setTitle(QString t) { title = t.remove(QChar('&')); setCaption(title); updatePixmap(); }		//!< set title to t
+	bool TitleEnabled() const { return title_enabled; }
+	void enableTitle(bool e=true) { title_enabled = e; updatePixmap(); }
 	void setTitleEnabled(bool e=true) { enableTitle(e); }
-	QDateTime TimeStamp() const { return timestamp; }								//!< get timestamp 
-	void setTimeStamp(QDateTime ts) { timestamp = ts; updatePixmap(); }			//!< set timestamp
-	bool TimeStampEnabled() const { return timestamp_enabled; }				//!< timestamp enabled?
-	void enableTimeStamp(bool e=true) { timestamp_enabled = e;updatePixmap(); }	//!< enable timestamp
+	QDateTime TimeStamp() const { return timestamp; }
+	void setTimeStamp(QDateTime ts) { timestamp = ts; updatePixmap(); }
+	bool TimeStampEnabled() const { return timestamp_enabled; }
+	void enableTimeStamp(bool e=true) { timestamp_enabled = e;updatePixmap(); }
 	void setTimeStampEnabled(bool e=true) { enableTimeStamp(e); }
-	QColor Background() const { return background; }							//!< get background color
-	void setBackground(QColor c) { background = c; updatePixmap(); }				//!< set background color to c
-	void setBackground(QString c) { setBackground(QColor(c)); }				//!< set background color to c
+	QBrush Background() const { return background; }						//!< get background color
+	void setBackground(QBrush c) { background = c; updatePixmap(); }				//!< set background color to c
+	void setBackground(QString c) { setBackground(QBrush(QColor(c))); }				//!< set background color to c
+	void setDrawObjectsFirst(bool v=true) { draw_objects_first = v; }
+	bool DrawObjectsFirst() { return draw_objects_first; }
 protected:
 	void resizeEvent( QResizeEvent * );
 	void paintEvent( QPaintEvent * );
@@ -180,7 +186,8 @@ protected:
 	void mouseMoveEvent( QMouseEvent * );
 	void keyPressEvent(QKeyEvent *);
 	void closeEvent(QCloseEvent *);
-	void Draw(QPainter *,int w, int h);
+	void Draw(QPainter *, int w, int h);
+	void DrawObjects(QPainter *, int w, int h);
 	void setupPrinter(KPrinter *pr, QString fn);
 	double XCoordinate(double x, double xmin, double xmax);
 	double YCoordinate(double y, double ymin, double ymax);
