@@ -5,7 +5,7 @@
 
 #include "formatlist.h"
 
-#define NR_COLUMNTYPES 6
-static const char* columnTypeItems[] = {"[X]","[Y]","[Z]","[DX]","[DY]","[DY2]",0};
+#define NR_COLUMNTYPES 8
+static const char* columnTypeItems[] = {"[X]","[Y]","[Z]","[DX]","[DY]","[DY2]","[LABEL]","[NONE]",0};
 
 #endif // SPREASHEETPROPERTIES_H
